@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/batch/Batch_EXPORTS.h>
@@ -21,6 +11,8 @@
 #include <aws/batch/model/ContainerProperties.h>
 #include <aws/batch/model/JobTimeout.h>
 #include <aws/batch/model/NodeProperties.h>
+#include <aws/core/utils/memory/stl/AWSVector.h>
+#include <aws/batch/model/PlatformCapability.h>
 #include <utility>
 
 namespace Aws
@@ -198,42 +190,74 @@ namespace Model
 
 
     /**
-     * <p>The type of job definition.</p>
+     * <p>The type of job definition. If the job is run on Fargate resources, then
+     * <code>multinode</code> isn't supported. For more information about multi-node
+     * parallel jobs, see <a
+     * href="https://docs.aws.amazon.com/batch/latest/userguide/multi-node-job-def.html">Creating
+     * a multi-node parallel job definition</a> in the <i>AWS Batch User Guide</i>.</p>
      */
     inline const Aws::String& GetType() const{ return m_type; }
 
     /**
-     * <p>The type of job definition.</p>
+     * <p>The type of job definition. If the job is run on Fargate resources, then
+     * <code>multinode</code> isn't supported. For more information about multi-node
+     * parallel jobs, see <a
+     * href="https://docs.aws.amazon.com/batch/latest/userguide/multi-node-job-def.html">Creating
+     * a multi-node parallel job definition</a> in the <i>AWS Batch User Guide</i>.</p>
      */
     inline bool TypeHasBeenSet() const { return m_typeHasBeenSet; }
 
     /**
-     * <p>The type of job definition.</p>
+     * <p>The type of job definition. If the job is run on Fargate resources, then
+     * <code>multinode</code> isn't supported. For more information about multi-node
+     * parallel jobs, see <a
+     * href="https://docs.aws.amazon.com/batch/latest/userguide/multi-node-job-def.html">Creating
+     * a multi-node parallel job definition</a> in the <i>AWS Batch User Guide</i>.</p>
      */
     inline void SetType(const Aws::String& value) { m_typeHasBeenSet = true; m_type = value; }
 
     /**
-     * <p>The type of job definition.</p>
+     * <p>The type of job definition. If the job is run on Fargate resources, then
+     * <code>multinode</code> isn't supported. For more information about multi-node
+     * parallel jobs, see <a
+     * href="https://docs.aws.amazon.com/batch/latest/userguide/multi-node-job-def.html">Creating
+     * a multi-node parallel job definition</a> in the <i>AWS Batch User Guide</i>.</p>
      */
     inline void SetType(Aws::String&& value) { m_typeHasBeenSet = true; m_type = std::move(value); }
 
     /**
-     * <p>The type of job definition.</p>
+     * <p>The type of job definition. If the job is run on Fargate resources, then
+     * <code>multinode</code> isn't supported. For more information about multi-node
+     * parallel jobs, see <a
+     * href="https://docs.aws.amazon.com/batch/latest/userguide/multi-node-job-def.html">Creating
+     * a multi-node parallel job definition</a> in the <i>AWS Batch User Guide</i>.</p>
      */
     inline void SetType(const char* value) { m_typeHasBeenSet = true; m_type.assign(value); }
 
     /**
-     * <p>The type of job definition.</p>
+     * <p>The type of job definition. If the job is run on Fargate resources, then
+     * <code>multinode</code> isn't supported. For more information about multi-node
+     * parallel jobs, see <a
+     * href="https://docs.aws.amazon.com/batch/latest/userguide/multi-node-job-def.html">Creating
+     * a multi-node parallel job definition</a> in the <i>AWS Batch User Guide</i>.</p>
      */
     inline JobDefinition& WithType(const Aws::String& value) { SetType(value); return *this;}
 
     /**
-     * <p>The type of job definition.</p>
+     * <p>The type of job definition. If the job is run on Fargate resources, then
+     * <code>multinode</code> isn't supported. For more information about multi-node
+     * parallel jobs, see <a
+     * href="https://docs.aws.amazon.com/batch/latest/userguide/multi-node-job-def.html">Creating
+     * a multi-node parallel job definition</a> in the <i>AWS Batch User Guide</i>.</p>
      */
     inline JobDefinition& WithType(Aws::String&& value) { SetType(std::move(value)); return *this;}
 
     /**
-     * <p>The type of job definition.</p>
+     * <p>The type of job definition. If the job is run on Fargate resources, then
+     * <code>multinode</code> isn't supported. For more information about multi-node
+     * parallel jobs, see <a
+     * href="https://docs.aws.amazon.com/batch/latest/userguide/multi-node-job-def.html">Creating
+     * a multi-node parallel job definition</a> in the <i>AWS Batch User Guide</i>.</p>
      */
     inline JobDefinition& WithType(const char* value) { SetType(value); return *this;}
 
@@ -453,76 +477,258 @@ namespace Model
     /**
      * <p>The timeout configuration for jobs that are submitted with this job
      * definition. You can specify a timeout duration after which AWS Batch terminates
-     * your jobs if they have not finished.</p>
+     * your jobs if they haven't finished.</p>
      */
     inline const JobTimeout& GetTimeout() const{ return m_timeout; }
 
     /**
      * <p>The timeout configuration for jobs that are submitted with this job
      * definition. You can specify a timeout duration after which AWS Batch terminates
-     * your jobs if they have not finished.</p>
+     * your jobs if they haven't finished.</p>
      */
     inline bool TimeoutHasBeenSet() const { return m_timeoutHasBeenSet; }
 
     /**
      * <p>The timeout configuration for jobs that are submitted with this job
      * definition. You can specify a timeout duration after which AWS Batch terminates
-     * your jobs if they have not finished.</p>
+     * your jobs if they haven't finished.</p>
      */
     inline void SetTimeout(const JobTimeout& value) { m_timeoutHasBeenSet = true; m_timeout = value; }
 
     /**
      * <p>The timeout configuration for jobs that are submitted with this job
      * definition. You can specify a timeout duration after which AWS Batch terminates
-     * your jobs if they have not finished.</p>
+     * your jobs if they haven't finished.</p>
      */
     inline void SetTimeout(JobTimeout&& value) { m_timeoutHasBeenSet = true; m_timeout = std::move(value); }
 
     /**
      * <p>The timeout configuration for jobs that are submitted with this job
      * definition. You can specify a timeout duration after which AWS Batch terminates
-     * your jobs if they have not finished.</p>
+     * your jobs if they haven't finished.</p>
      */
     inline JobDefinition& WithTimeout(const JobTimeout& value) { SetTimeout(value); return *this;}
 
     /**
      * <p>The timeout configuration for jobs that are submitted with this job
      * definition. You can specify a timeout duration after which AWS Batch terminates
-     * your jobs if they have not finished.</p>
+     * your jobs if they haven't finished.</p>
      */
     inline JobDefinition& WithTimeout(JobTimeout&& value) { SetTimeout(std::move(value)); return *this;}
 
 
     /**
      * <p>An object with various properties specific to multi-node parallel jobs.</p>
+     *  <p>If the job runs on Fargate resources, then you must not specify
+     * <code>nodeProperties</code>; use <code>containerProperties</code> instead.</p>
+     * 
      */
     inline const NodeProperties& GetNodeProperties() const{ return m_nodeProperties; }
 
     /**
      * <p>An object with various properties specific to multi-node parallel jobs.</p>
+     *  <p>If the job runs on Fargate resources, then you must not specify
+     * <code>nodeProperties</code>; use <code>containerProperties</code> instead.</p>
+     * 
      */
     inline bool NodePropertiesHasBeenSet() const { return m_nodePropertiesHasBeenSet; }
 
     /**
      * <p>An object with various properties specific to multi-node parallel jobs.</p>
+     *  <p>If the job runs on Fargate resources, then you must not specify
+     * <code>nodeProperties</code>; use <code>containerProperties</code> instead.</p>
+     * 
      */
     inline void SetNodeProperties(const NodeProperties& value) { m_nodePropertiesHasBeenSet = true; m_nodeProperties = value; }
 
     /**
      * <p>An object with various properties specific to multi-node parallel jobs.</p>
+     *  <p>If the job runs on Fargate resources, then you must not specify
+     * <code>nodeProperties</code>; use <code>containerProperties</code> instead.</p>
+     * 
      */
     inline void SetNodeProperties(NodeProperties&& value) { m_nodePropertiesHasBeenSet = true; m_nodeProperties = std::move(value); }
 
     /**
      * <p>An object with various properties specific to multi-node parallel jobs.</p>
+     *  <p>If the job runs on Fargate resources, then you must not specify
+     * <code>nodeProperties</code>; use <code>containerProperties</code> instead.</p>
+     * 
      */
     inline JobDefinition& WithNodeProperties(const NodeProperties& value) { SetNodeProperties(value); return *this;}
 
     /**
      * <p>An object with various properties specific to multi-node parallel jobs.</p>
+     *  <p>If the job runs on Fargate resources, then you must not specify
+     * <code>nodeProperties</code>; use <code>containerProperties</code> instead.</p>
+     * 
      */
     inline JobDefinition& WithNodeProperties(NodeProperties&& value) { SetNodeProperties(std::move(value)); return *this;}
 
+
+    /**
+     * <p>The tags applied to the job definition.</p>
+     */
+    inline const Aws::Map<Aws::String, Aws::String>& GetTags() const{ return m_tags; }
+
+    /**
+     * <p>The tags applied to the job definition.</p>
+     */
+    inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
+
+    /**
+     * <p>The tags applied to the job definition.</p>
+     */
+    inline void SetTags(const Aws::Map<Aws::String, Aws::String>& value) { m_tagsHasBeenSet = true; m_tags = value; }
+
+    /**
+     * <p>The tags applied to the job definition.</p>
+     */
+    inline void SetTags(Aws::Map<Aws::String, Aws::String>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
+
+    /**
+     * <p>The tags applied to the job definition.</p>
+     */
+    inline JobDefinition& WithTags(const Aws::Map<Aws::String, Aws::String>& value) { SetTags(value); return *this;}
+
+    /**
+     * <p>The tags applied to the job definition.</p>
+     */
+    inline JobDefinition& WithTags(Aws::Map<Aws::String, Aws::String>&& value) { SetTags(std::move(value)); return *this;}
+
+    /**
+     * <p>The tags applied to the job definition.</p>
+     */
+    inline JobDefinition& AddTags(const Aws::String& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
+
+    /**
+     * <p>The tags applied to the job definition.</p>
+     */
+    inline JobDefinition& AddTags(Aws::String&& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
+
+    /**
+     * <p>The tags applied to the job definition.</p>
+     */
+    inline JobDefinition& AddTags(const Aws::String& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
+
+    /**
+     * <p>The tags applied to the job definition.</p>
+     */
+    inline JobDefinition& AddTags(Aws::String&& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), std::move(value)); return *this; }
+
+    /**
+     * <p>The tags applied to the job definition.</p>
+     */
+    inline JobDefinition& AddTags(const char* key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
+
+    /**
+     * <p>The tags applied to the job definition.</p>
+     */
+    inline JobDefinition& AddTags(Aws::String&& key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
+
+    /**
+     * <p>The tags applied to the job definition.</p>
+     */
+    inline JobDefinition& AddTags(const char* key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
+
+
+    /**
+     * <p>Specifies whether to propagate the tags from the job or job definition to the
+     * corresponding Amazon ECS task. If no value is specified, the tags aren't
+     * propagated. Tags can only be propagated to the tasks during task creation. For
+     * tags with the same name, job tags are given priority over job definitions tags.
+     * If the total number of combined tags from the job and job definition is over 50,
+     * the job is moved to the <code>FAILED</code> state.</p>
+     */
+    inline bool GetPropagateTags() const{ return m_propagateTags; }
+
+    /**
+     * <p>Specifies whether to propagate the tags from the job or job definition to the
+     * corresponding Amazon ECS task. If no value is specified, the tags aren't
+     * propagated. Tags can only be propagated to the tasks during task creation. For
+     * tags with the same name, job tags are given priority over job definitions tags.
+     * If the total number of combined tags from the job and job definition is over 50,
+     * the job is moved to the <code>FAILED</code> state.</p>
+     */
+    inline bool PropagateTagsHasBeenSet() const { return m_propagateTagsHasBeenSet; }
+
+    /**
+     * <p>Specifies whether to propagate the tags from the job or job definition to the
+     * corresponding Amazon ECS task. If no value is specified, the tags aren't
+     * propagated. Tags can only be propagated to the tasks during task creation. For
+     * tags with the same name, job tags are given priority over job definitions tags.
+     * If the total number of combined tags from the job and job definition is over 50,
+     * the job is moved to the <code>FAILED</code> state.</p>
+     */
+    inline void SetPropagateTags(bool value) { m_propagateTagsHasBeenSet = true; m_propagateTags = value; }
+
+    /**
+     * <p>Specifies whether to propagate the tags from the job or job definition to the
+     * corresponding Amazon ECS task. If no value is specified, the tags aren't
+     * propagated. Tags can only be propagated to the tasks during task creation. For
+     * tags with the same name, job tags are given priority over job definitions tags.
+     * If the total number of combined tags from the job and job definition is over 50,
+     * the job is moved to the <code>FAILED</code> state.</p>
+     */
+    inline JobDefinition& WithPropagateTags(bool value) { SetPropagateTags(value); return *this;}
+
+
+    /**
+     * <p>The platform capabilities required by the job definition. If no value is
+     * specified, it defaults to <code>EC2</code>. Jobs run on Fargate resources
+     * specify <code>FARGATE</code>.</p>
+     */
+    inline const Aws::Vector<PlatformCapability>& GetPlatformCapabilities() const{ return m_platformCapabilities; }
+
+    /**
+     * <p>The platform capabilities required by the job definition. If no value is
+     * specified, it defaults to <code>EC2</code>. Jobs run on Fargate resources
+     * specify <code>FARGATE</code>.</p>
+     */
+    inline bool PlatformCapabilitiesHasBeenSet() const { return m_platformCapabilitiesHasBeenSet; }
+
+    /**
+     * <p>The platform capabilities required by the job definition. If no value is
+     * specified, it defaults to <code>EC2</code>. Jobs run on Fargate resources
+     * specify <code>FARGATE</code>.</p>
+     */
+    inline void SetPlatformCapabilities(const Aws::Vector<PlatformCapability>& value) { m_platformCapabilitiesHasBeenSet = true; m_platformCapabilities = value; }
+
+    /**
+     * <p>The platform capabilities required by the job definition. If no value is
+     * specified, it defaults to <code>EC2</code>. Jobs run on Fargate resources
+     * specify <code>FARGATE</code>.</p>
+     */
+    inline void SetPlatformCapabilities(Aws::Vector<PlatformCapability>&& value) { m_platformCapabilitiesHasBeenSet = true; m_platformCapabilities = std::move(value); }
+
+    /**
+     * <p>The platform capabilities required by the job definition. If no value is
+     * specified, it defaults to <code>EC2</code>. Jobs run on Fargate resources
+     * specify <code>FARGATE</code>.</p>
+     */
+    inline JobDefinition& WithPlatformCapabilities(const Aws::Vector<PlatformCapability>& value) { SetPlatformCapabilities(value); return *this;}
+
+    /**
+     * <p>The platform capabilities required by the job definition. If no value is
+     * specified, it defaults to <code>EC2</code>. Jobs run on Fargate resources
+     * specify <code>FARGATE</code>.</p>
+     */
+    inline JobDefinition& WithPlatformCapabilities(Aws::Vector<PlatformCapability>&& value) { SetPlatformCapabilities(std::move(value)); return *this;}
+
+    /**
+     * <p>The platform capabilities required by the job definition. If no value is
+     * specified, it defaults to <code>EC2</code>. Jobs run on Fargate resources
+     * specify <code>FARGATE</code>.</p>
+     */
+    inline JobDefinition& AddPlatformCapabilities(const PlatformCapability& value) { m_platformCapabilitiesHasBeenSet = true; m_platformCapabilities.push_back(value); return *this; }
+
+    /**
+     * <p>The platform capabilities required by the job definition. If no value is
+     * specified, it defaults to <code>EC2</code>. Jobs run on Fargate resources
+     * specify <code>FARGATE</code>.</p>
+     */
+    inline JobDefinition& AddPlatformCapabilities(PlatformCapability&& value) { m_platformCapabilitiesHasBeenSet = true; m_platformCapabilities.push_back(std::move(value)); return *this; }
+
   private:
 
     Aws::String m_jobDefinitionName;
@@ -554,6 +760,15 @@ namespace Model
 
     NodeProperties m_nodeProperties;
     bool m_nodePropertiesHasBeenSet;
+
+    Aws::Map<Aws::String, Aws::String> m_tags;
+    bool m_tagsHasBeenSet;
+
+    bool m_propagateTags;
+    bool m_propagateTagsHasBeenSet;
+
+    Aws::Vector<PlatformCapability> m_platformCapabilities;
+    bool m_platformCapabilitiesHasBeenSet;
   };
 
 } // namespace Model
