@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/ec2/EC2_EXPORTS.h>
@@ -26,6 +16,7 @@
 #include <aws/ec2/model/DeviceType.h>
 #include <aws/ec2/model/StateReason.h>
 #include <aws/ec2/model/VirtualizationType.h>
+#include <aws/ec2/model/BootModeValues.h>
 #include <aws/ec2/model/ProductCode.h>
 #include <aws/ec2/model/BlockDeviceMapping.h>
 #include <aws/ec2/model/Tag.h>
@@ -405,7 +396,7 @@ namespace Model
     /**
      * <p>The platform details associated with the billing code of the AMI. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/billing-info.html">AMI
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-billing-info.html">Obtaining
      * Billing Information</a> in the <i>Amazon Elastic Compute Cloud User
      * Guide</i>.</p>
      */
@@ -414,7 +405,7 @@ namespace Model
     /**
      * <p>The platform details associated with the billing code of the AMI. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/billing-info.html">AMI
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-billing-info.html">Obtaining
      * Billing Information</a> in the <i>Amazon Elastic Compute Cloud User
      * Guide</i>.</p>
      */
@@ -423,7 +414,7 @@ namespace Model
     /**
      * <p>The platform details associated with the billing code of the AMI. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/billing-info.html">AMI
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-billing-info.html">Obtaining
      * Billing Information</a> in the <i>Amazon Elastic Compute Cloud User
      * Guide</i>.</p>
      */
@@ -432,7 +423,7 @@ namespace Model
     /**
      * <p>The platform details associated with the billing code of the AMI. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/billing-info.html">AMI
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-billing-info.html">Obtaining
      * Billing Information</a> in the <i>Amazon Elastic Compute Cloud User
      * Guide</i>.</p>
      */
@@ -441,7 +432,7 @@ namespace Model
     /**
      * <p>The platform details associated with the billing code of the AMI. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/billing-info.html">AMI
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-billing-info.html">Obtaining
      * Billing Information</a> in the <i>Amazon Elastic Compute Cloud User
      * Guide</i>.</p>
      */
@@ -450,7 +441,7 @@ namespace Model
     /**
      * <p>The platform details associated with the billing code of the AMI. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/billing-info.html">AMI
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-billing-info.html">Obtaining
      * Billing Information</a> in the <i>Amazon Elastic Compute Cloud User
      * Guide</i>.</p>
      */
@@ -459,7 +450,7 @@ namespace Model
     /**
      * <p>The platform details associated with the billing code of the AMI. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/billing-info.html">AMI
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-billing-info.html">Obtaining
      * Billing Information</a> in the <i>Amazon Elastic Compute Cloud User
      * Guide</i>.</p>
      */
@@ -468,7 +459,7 @@ namespace Model
     /**
      * <p>The platform details associated with the billing code of the AMI. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/billing-info.html">AMI
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-billing-info.html">Obtaining
      * Billing Information</a> in the <i>Amazon Elastic Compute Cloud User
      * Guide</i>.</p>
      */
@@ -476,90 +467,106 @@ namespace Model
 
 
     /**
-     * <p>The operation of the Amazon EC2 instance and the billing code associated with
-     * the AMI. <code>usageOperation</code> corresponds to the <a
+     * <p>The operation of the Amazon EC2 instance and the billing code that is
+     * associated with the AMI. <code>usageOperation</code> corresponds to the <a
      * href="https://docs.aws.amazon.com/cur/latest/userguide/Lineitem-columns.html#Lineitem-details-O-Operation">lineitem/Operation</a>
-     * column on your AWS Cost and Usage Report. For more information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/billing-info.html">AMI
-     * Billing Information</a> in the <i>Amazon Elastic Compute Cloud User
-     * Guide</i>.</p>
+     * column on your AWS Cost and Usage Report and in the <a
+     * href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/price-changes.html">AWS
+     * Price List API</a>. For the list of <code>UsageOperation</code> codes, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-billing-info.html#billing-info">Platform
+     * Details and Usage Operation Billing Codes</a> in the <i>Amazon Elastic Compute
+     * Cloud User Guide</i>.</p>
      */
     inline const Aws::String& GetUsageOperation() const{ return m_usageOperation; }
 
     /**
-     * <p>The operation of the Amazon EC2 instance and the billing code associated with
-     * the AMI. <code>usageOperation</code> corresponds to the <a
+     * <p>The operation of the Amazon EC2 instance and the billing code that is
+     * associated with the AMI. <code>usageOperation</code> corresponds to the <a
      * href="https://docs.aws.amazon.com/cur/latest/userguide/Lineitem-columns.html#Lineitem-details-O-Operation">lineitem/Operation</a>
-     * column on your AWS Cost and Usage Report. For more information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/billing-info.html">AMI
-     * Billing Information</a> in the <i>Amazon Elastic Compute Cloud User
-     * Guide</i>.</p>
+     * column on your AWS Cost and Usage Report and in the <a
+     * href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/price-changes.html">AWS
+     * Price List API</a>. For the list of <code>UsageOperation</code> codes, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-billing-info.html#billing-info">Platform
+     * Details and Usage Operation Billing Codes</a> in the <i>Amazon Elastic Compute
+     * Cloud User Guide</i>.</p>
      */
     inline bool UsageOperationHasBeenSet() const { return m_usageOperationHasBeenSet; }
 
     /**
-     * <p>The operation of the Amazon EC2 instance and the billing code associated with
-     * the AMI. <code>usageOperation</code> corresponds to the <a
+     * <p>The operation of the Amazon EC2 instance and the billing code that is
+     * associated with the AMI. <code>usageOperation</code> corresponds to the <a
      * href="https://docs.aws.amazon.com/cur/latest/userguide/Lineitem-columns.html#Lineitem-details-O-Operation">lineitem/Operation</a>
-     * column on your AWS Cost and Usage Report. For more information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/billing-info.html">AMI
-     * Billing Information</a> in the <i>Amazon Elastic Compute Cloud User
-     * Guide</i>.</p>
+     * column on your AWS Cost and Usage Report and in the <a
+     * href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/price-changes.html">AWS
+     * Price List API</a>. For the list of <code>UsageOperation</code> codes, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-billing-info.html#billing-info">Platform
+     * Details and Usage Operation Billing Codes</a> in the <i>Amazon Elastic Compute
+     * Cloud User Guide</i>.</p>
      */
     inline void SetUsageOperation(const Aws::String& value) { m_usageOperationHasBeenSet = true; m_usageOperation = value; }
 
     /**
-     * <p>The operation of the Amazon EC2 instance and the billing code associated with
-     * the AMI. <code>usageOperation</code> corresponds to the <a
+     * <p>The operation of the Amazon EC2 instance and the billing code that is
+     * associated with the AMI. <code>usageOperation</code> corresponds to the <a
      * href="https://docs.aws.amazon.com/cur/latest/userguide/Lineitem-columns.html#Lineitem-details-O-Operation">lineitem/Operation</a>
-     * column on your AWS Cost and Usage Report. For more information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/billing-info.html">AMI
-     * Billing Information</a> in the <i>Amazon Elastic Compute Cloud User
-     * Guide</i>.</p>
+     * column on your AWS Cost and Usage Report and in the <a
+     * href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/price-changes.html">AWS
+     * Price List API</a>. For the list of <code>UsageOperation</code> codes, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-billing-info.html#billing-info">Platform
+     * Details and Usage Operation Billing Codes</a> in the <i>Amazon Elastic Compute
+     * Cloud User Guide</i>.</p>
      */
     inline void SetUsageOperation(Aws::String&& value) { m_usageOperationHasBeenSet = true; m_usageOperation = std::move(value); }
 
     /**
-     * <p>The operation of the Amazon EC2 instance and the billing code associated with
-     * the AMI. <code>usageOperation</code> corresponds to the <a
+     * <p>The operation of the Amazon EC2 instance and the billing code that is
+     * associated with the AMI. <code>usageOperation</code> corresponds to the <a
      * href="https://docs.aws.amazon.com/cur/latest/userguide/Lineitem-columns.html#Lineitem-details-O-Operation">lineitem/Operation</a>
-     * column on your AWS Cost and Usage Report. For more information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/billing-info.html">AMI
-     * Billing Information</a> in the <i>Amazon Elastic Compute Cloud User
-     * Guide</i>.</p>
+     * column on your AWS Cost and Usage Report and in the <a
+     * href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/price-changes.html">AWS
+     * Price List API</a>. For the list of <code>UsageOperation</code> codes, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-billing-info.html#billing-info">Platform
+     * Details and Usage Operation Billing Codes</a> in the <i>Amazon Elastic Compute
+     * Cloud User Guide</i>.</p>
      */
     inline void SetUsageOperation(const char* value) { m_usageOperationHasBeenSet = true; m_usageOperation.assign(value); }
 
     /**
-     * <p>The operation of the Amazon EC2 instance and the billing code associated with
-     * the AMI. <code>usageOperation</code> corresponds to the <a
+     * <p>The operation of the Amazon EC2 instance and the billing code that is
+     * associated with the AMI. <code>usageOperation</code> corresponds to the <a
      * href="https://docs.aws.amazon.com/cur/latest/userguide/Lineitem-columns.html#Lineitem-details-O-Operation">lineitem/Operation</a>
-     * column on your AWS Cost and Usage Report. For more information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/billing-info.html">AMI
-     * Billing Information</a> in the <i>Amazon Elastic Compute Cloud User
-     * Guide</i>.</p>
+     * column on your AWS Cost and Usage Report and in the <a
+     * href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/price-changes.html">AWS
+     * Price List API</a>. For the list of <code>UsageOperation</code> codes, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-billing-info.html#billing-info">Platform
+     * Details and Usage Operation Billing Codes</a> in the <i>Amazon Elastic Compute
+     * Cloud User Guide</i>.</p>
      */
     inline Image& WithUsageOperation(const Aws::String& value) { SetUsageOperation(value); return *this;}
 
     /**
-     * <p>The operation of the Amazon EC2 instance and the billing code associated with
-     * the AMI. <code>usageOperation</code> corresponds to the <a
+     * <p>The operation of the Amazon EC2 instance and the billing code that is
+     * associated with the AMI. <code>usageOperation</code> corresponds to the <a
      * href="https://docs.aws.amazon.com/cur/latest/userguide/Lineitem-columns.html#Lineitem-details-O-Operation">lineitem/Operation</a>
-     * column on your AWS Cost and Usage Report. For more information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/billing-info.html">AMI
-     * Billing Information</a> in the <i>Amazon Elastic Compute Cloud User
-     * Guide</i>.</p>
+     * column on your AWS Cost and Usage Report and in the <a
+     * href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/price-changes.html">AWS
+     * Price List API</a>. For the list of <code>UsageOperation</code> codes, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-billing-info.html#billing-info">Platform
+     * Details and Usage Operation Billing Codes</a> in the <i>Amazon Elastic Compute
+     * Cloud User Guide</i>.</p>
      */
     inline Image& WithUsageOperation(Aws::String&& value) { SetUsageOperation(std::move(value)); return *this;}
 
     /**
-     * <p>The operation of the Amazon EC2 instance and the billing code associated with
-     * the AMI. <code>usageOperation</code> corresponds to the <a
+     * <p>The operation of the Amazon EC2 instance and the billing code that is
+     * associated with the AMI. <code>usageOperation</code> corresponds to the <a
      * href="https://docs.aws.amazon.com/cur/latest/userguide/Lineitem-columns.html#Lineitem-details-O-Operation">lineitem/Operation</a>
-     * column on your AWS Cost and Usage Report. For more information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/billing-info.html">AMI
-     * Billing Information</a> in the <i>Amazon Elastic Compute Cloud User
-     * Guide</i>.</p>
+     * column on your AWS Cost and Usage Report and in the <a
+     * href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/price-changes.html">AWS
+     * Price List API</a>. For the list of <code>UsageOperation</code> codes, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-billing-info.html#billing-info">Platform
+     * Details and Usage Operation Billing Codes</a> in the <i>Amazon Elastic Compute
+     * Cloud User Guide</i>.</p>
      */
     inline Image& WithUsageOperation(const char* value) { SetUsageOperation(value); return *this;}
 
@@ -1152,6 +1159,49 @@ namespace Model
      */
     inline Image& WithVirtualizationType(VirtualizationType&& value) { SetVirtualizationType(std::move(value)); return *this;}
 
+
+    /**
+     * <p>The boot mode of the image. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-boot.html">Boot
+     * modes</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
+     */
+    inline const BootModeValues& GetBootMode() const{ return m_bootMode; }
+
+    /**
+     * <p>The boot mode of the image. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-boot.html">Boot
+     * modes</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
+     */
+    inline bool BootModeHasBeenSet() const { return m_bootModeHasBeenSet; }
+
+    /**
+     * <p>The boot mode of the image. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-boot.html">Boot
+     * modes</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
+     */
+    inline void SetBootMode(const BootModeValues& value) { m_bootModeHasBeenSet = true; m_bootMode = value; }
+
+    /**
+     * <p>The boot mode of the image. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-boot.html">Boot
+     * modes</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
+     */
+    inline void SetBootMode(BootModeValues&& value) { m_bootModeHasBeenSet = true; m_bootMode = std::move(value); }
+
+    /**
+     * <p>The boot mode of the image. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-boot.html">Boot
+     * modes</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
+     */
+    inline Image& WithBootMode(const BootModeValues& value) { SetBootMode(value); return *this;}
+
+    /**
+     * <p>The boot mode of the image. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-boot.html">Boot
+     * modes</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
+     */
+    inline Image& WithBootMode(BootModeValues&& value) { SetBootMode(std::move(value)); return *this;}
+
   private:
 
     ArchitectureValues m_architecture;
@@ -1231,6 +1281,9 @@ namespace Model
 
     VirtualizationType m_virtualizationType;
     bool m_virtualizationTypeHasBeenSet;
+
+    BootModeValues m_bootMode;
+    bool m_bootModeHasBeenSet;
   };
 
 } // namespace Model
