@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/ecs/ECS_EXPORTS.h>
@@ -54,194 +44,74 @@ namespace Model
 
 
     /**
-     * <p>The capacity provider strategy to use for the task.</p> <p>A capacity
-     * provider strategy consists of one or more capacity providers along with the
-     * <code>base</code> and <code>weight</code> to assign to them. A capacity provider
-     * must be associated with the cluster to be used in a capacity provider strategy.
-     * The <a>PutClusterCapacityProviders</a> API is used to associate a capacity
-     * provider with a cluster. Only capacity providers with an <code>ACTIVE</code> or
-     * <code>UPDATING</code> status can be used.</p> <p>If a
+     * <p>The capacity provider strategy to use for the task.</p> <p>If a
      * <code>capacityProviderStrategy</code> is specified, the <code>launchType</code>
      * parameter must be omitted. If no <code>capacityProviderStrategy</code> or
      * <code>launchType</code> is specified, the
-     * <code>defaultCapacityProviderStrategy</code> for the cluster is used.</p> <p>If
-     * specifying a capacity provider that uses an Auto Scaling group, the capacity
-     * provider must already be created. New capacity providers can be created with the
-     * <a>CreateCapacityProvider</a> API operation.</p> <p>To use a AWS Fargate
-     * capacity provider, specify either the <code>FARGATE</code> or
-     * <code>FARGATE_SPOT</code> capacity providers. The AWS Fargate capacity providers
-     * are available to all accounts and only need to be associated with a cluster to
-     * be used.</p> <p>The <a>PutClusterCapacityProviders</a> API operation is used to
-     * update the list of available capacity providers for a cluster after the cluster
-     * is created.</p>
+     * <code>defaultCapacityProviderStrategy</code> for the cluster is used.</p>
      */
     inline const Aws::Vector<CapacityProviderStrategyItem>& GetCapacityProviderStrategy() const{ return m_capacityProviderStrategy; }
 
     /**
-     * <p>The capacity provider strategy to use for the task.</p> <p>A capacity
-     * provider strategy consists of one or more capacity providers along with the
-     * <code>base</code> and <code>weight</code> to assign to them. A capacity provider
-     * must be associated with the cluster to be used in a capacity provider strategy.
-     * The <a>PutClusterCapacityProviders</a> API is used to associate a capacity
-     * provider with a cluster. Only capacity providers with an <code>ACTIVE</code> or
-     * <code>UPDATING</code> status can be used.</p> <p>If a
+     * <p>The capacity provider strategy to use for the task.</p> <p>If a
      * <code>capacityProviderStrategy</code> is specified, the <code>launchType</code>
      * parameter must be omitted. If no <code>capacityProviderStrategy</code> or
      * <code>launchType</code> is specified, the
-     * <code>defaultCapacityProviderStrategy</code> for the cluster is used.</p> <p>If
-     * specifying a capacity provider that uses an Auto Scaling group, the capacity
-     * provider must already be created. New capacity providers can be created with the
-     * <a>CreateCapacityProvider</a> API operation.</p> <p>To use a AWS Fargate
-     * capacity provider, specify either the <code>FARGATE</code> or
-     * <code>FARGATE_SPOT</code> capacity providers. The AWS Fargate capacity providers
-     * are available to all accounts and only need to be associated with a cluster to
-     * be used.</p> <p>The <a>PutClusterCapacityProviders</a> API operation is used to
-     * update the list of available capacity providers for a cluster after the cluster
-     * is created.</p>
+     * <code>defaultCapacityProviderStrategy</code> for the cluster is used.</p>
      */
     inline bool CapacityProviderStrategyHasBeenSet() const { return m_capacityProviderStrategyHasBeenSet; }
 
     /**
-     * <p>The capacity provider strategy to use for the task.</p> <p>A capacity
-     * provider strategy consists of one or more capacity providers along with the
-     * <code>base</code> and <code>weight</code> to assign to them. A capacity provider
-     * must be associated with the cluster to be used in a capacity provider strategy.
-     * The <a>PutClusterCapacityProviders</a> API is used to associate a capacity
-     * provider with a cluster. Only capacity providers with an <code>ACTIVE</code> or
-     * <code>UPDATING</code> status can be used.</p> <p>If a
+     * <p>The capacity provider strategy to use for the task.</p> <p>If a
      * <code>capacityProviderStrategy</code> is specified, the <code>launchType</code>
      * parameter must be omitted. If no <code>capacityProviderStrategy</code> or
      * <code>launchType</code> is specified, the
-     * <code>defaultCapacityProviderStrategy</code> for the cluster is used.</p> <p>If
-     * specifying a capacity provider that uses an Auto Scaling group, the capacity
-     * provider must already be created. New capacity providers can be created with the
-     * <a>CreateCapacityProvider</a> API operation.</p> <p>To use a AWS Fargate
-     * capacity provider, specify either the <code>FARGATE</code> or
-     * <code>FARGATE_SPOT</code> capacity providers. The AWS Fargate capacity providers
-     * are available to all accounts and only need to be associated with a cluster to
-     * be used.</p> <p>The <a>PutClusterCapacityProviders</a> API operation is used to
-     * update the list of available capacity providers for a cluster after the cluster
-     * is created.</p>
+     * <code>defaultCapacityProviderStrategy</code> for the cluster is used.</p>
      */
     inline void SetCapacityProviderStrategy(const Aws::Vector<CapacityProviderStrategyItem>& value) { m_capacityProviderStrategyHasBeenSet = true; m_capacityProviderStrategy = value; }
 
     /**
-     * <p>The capacity provider strategy to use for the task.</p> <p>A capacity
-     * provider strategy consists of one or more capacity providers along with the
-     * <code>base</code> and <code>weight</code> to assign to them. A capacity provider
-     * must be associated with the cluster to be used in a capacity provider strategy.
-     * The <a>PutClusterCapacityProviders</a> API is used to associate a capacity
-     * provider with a cluster. Only capacity providers with an <code>ACTIVE</code> or
-     * <code>UPDATING</code> status can be used.</p> <p>If a
+     * <p>The capacity provider strategy to use for the task.</p> <p>If a
      * <code>capacityProviderStrategy</code> is specified, the <code>launchType</code>
      * parameter must be omitted. If no <code>capacityProviderStrategy</code> or
      * <code>launchType</code> is specified, the
-     * <code>defaultCapacityProviderStrategy</code> for the cluster is used.</p> <p>If
-     * specifying a capacity provider that uses an Auto Scaling group, the capacity
-     * provider must already be created. New capacity providers can be created with the
-     * <a>CreateCapacityProvider</a> API operation.</p> <p>To use a AWS Fargate
-     * capacity provider, specify either the <code>FARGATE</code> or
-     * <code>FARGATE_SPOT</code> capacity providers. The AWS Fargate capacity providers
-     * are available to all accounts and only need to be associated with a cluster to
-     * be used.</p> <p>The <a>PutClusterCapacityProviders</a> API operation is used to
-     * update the list of available capacity providers for a cluster after the cluster
-     * is created.</p>
+     * <code>defaultCapacityProviderStrategy</code> for the cluster is used.</p>
      */
     inline void SetCapacityProviderStrategy(Aws::Vector<CapacityProviderStrategyItem>&& value) { m_capacityProviderStrategyHasBeenSet = true; m_capacityProviderStrategy = std::move(value); }
 
     /**
-     * <p>The capacity provider strategy to use for the task.</p> <p>A capacity
-     * provider strategy consists of one or more capacity providers along with the
-     * <code>base</code> and <code>weight</code> to assign to them. A capacity provider
-     * must be associated with the cluster to be used in a capacity provider strategy.
-     * The <a>PutClusterCapacityProviders</a> API is used to associate a capacity
-     * provider with a cluster. Only capacity providers with an <code>ACTIVE</code> or
-     * <code>UPDATING</code> status can be used.</p> <p>If a
+     * <p>The capacity provider strategy to use for the task.</p> <p>If a
      * <code>capacityProviderStrategy</code> is specified, the <code>launchType</code>
      * parameter must be omitted. If no <code>capacityProviderStrategy</code> or
      * <code>launchType</code> is specified, the
-     * <code>defaultCapacityProviderStrategy</code> for the cluster is used.</p> <p>If
-     * specifying a capacity provider that uses an Auto Scaling group, the capacity
-     * provider must already be created. New capacity providers can be created with the
-     * <a>CreateCapacityProvider</a> API operation.</p> <p>To use a AWS Fargate
-     * capacity provider, specify either the <code>FARGATE</code> or
-     * <code>FARGATE_SPOT</code> capacity providers. The AWS Fargate capacity providers
-     * are available to all accounts and only need to be associated with a cluster to
-     * be used.</p> <p>The <a>PutClusterCapacityProviders</a> API operation is used to
-     * update the list of available capacity providers for a cluster after the cluster
-     * is created.</p>
+     * <code>defaultCapacityProviderStrategy</code> for the cluster is used.</p>
      */
     inline RunTaskRequest& WithCapacityProviderStrategy(const Aws::Vector<CapacityProviderStrategyItem>& value) { SetCapacityProviderStrategy(value); return *this;}
 
     /**
-     * <p>The capacity provider strategy to use for the task.</p> <p>A capacity
-     * provider strategy consists of one or more capacity providers along with the
-     * <code>base</code> and <code>weight</code> to assign to them. A capacity provider
-     * must be associated with the cluster to be used in a capacity provider strategy.
-     * The <a>PutClusterCapacityProviders</a> API is used to associate a capacity
-     * provider with a cluster. Only capacity providers with an <code>ACTIVE</code> or
-     * <code>UPDATING</code> status can be used.</p> <p>If a
+     * <p>The capacity provider strategy to use for the task.</p> <p>If a
      * <code>capacityProviderStrategy</code> is specified, the <code>launchType</code>
      * parameter must be omitted. If no <code>capacityProviderStrategy</code> or
      * <code>launchType</code> is specified, the
-     * <code>defaultCapacityProviderStrategy</code> for the cluster is used.</p> <p>If
-     * specifying a capacity provider that uses an Auto Scaling group, the capacity
-     * provider must already be created. New capacity providers can be created with the
-     * <a>CreateCapacityProvider</a> API operation.</p> <p>To use a AWS Fargate
-     * capacity provider, specify either the <code>FARGATE</code> or
-     * <code>FARGATE_SPOT</code> capacity providers. The AWS Fargate capacity providers
-     * are available to all accounts and only need to be associated with a cluster to
-     * be used.</p> <p>The <a>PutClusterCapacityProviders</a> API operation is used to
-     * update the list of available capacity providers for a cluster after the cluster
-     * is created.</p>
+     * <code>defaultCapacityProviderStrategy</code> for the cluster is used.</p>
      */
     inline RunTaskRequest& WithCapacityProviderStrategy(Aws::Vector<CapacityProviderStrategyItem>&& value) { SetCapacityProviderStrategy(std::move(value)); return *this;}
 
     /**
-     * <p>The capacity provider strategy to use for the task.</p> <p>A capacity
-     * provider strategy consists of one or more capacity providers along with the
-     * <code>base</code> and <code>weight</code> to assign to them. A capacity provider
-     * must be associated with the cluster to be used in a capacity provider strategy.
-     * The <a>PutClusterCapacityProviders</a> API is used to associate a capacity
-     * provider with a cluster. Only capacity providers with an <code>ACTIVE</code> or
-     * <code>UPDATING</code> status can be used.</p> <p>If a
+     * <p>The capacity provider strategy to use for the task.</p> <p>If a
      * <code>capacityProviderStrategy</code> is specified, the <code>launchType</code>
      * parameter must be omitted. If no <code>capacityProviderStrategy</code> or
      * <code>launchType</code> is specified, the
-     * <code>defaultCapacityProviderStrategy</code> for the cluster is used.</p> <p>If
-     * specifying a capacity provider that uses an Auto Scaling group, the capacity
-     * provider must already be created. New capacity providers can be created with the
-     * <a>CreateCapacityProvider</a> API operation.</p> <p>To use a AWS Fargate
-     * capacity provider, specify either the <code>FARGATE</code> or
-     * <code>FARGATE_SPOT</code> capacity providers. The AWS Fargate capacity providers
-     * are available to all accounts and only need to be associated with a cluster to
-     * be used.</p> <p>The <a>PutClusterCapacityProviders</a> API operation is used to
-     * update the list of available capacity providers for a cluster after the cluster
-     * is created.</p>
+     * <code>defaultCapacityProviderStrategy</code> for the cluster is used.</p>
      */
     inline RunTaskRequest& AddCapacityProviderStrategy(const CapacityProviderStrategyItem& value) { m_capacityProviderStrategyHasBeenSet = true; m_capacityProviderStrategy.push_back(value); return *this; }
 
     /**
-     * <p>The capacity provider strategy to use for the task.</p> <p>A capacity
-     * provider strategy consists of one or more capacity providers along with the
-     * <code>base</code> and <code>weight</code> to assign to them. A capacity provider
-     * must be associated with the cluster to be used in a capacity provider strategy.
-     * The <a>PutClusterCapacityProviders</a> API is used to associate a capacity
-     * provider with a cluster. Only capacity providers with an <code>ACTIVE</code> or
-     * <code>UPDATING</code> status can be used.</p> <p>If a
+     * <p>The capacity provider strategy to use for the task.</p> <p>If a
      * <code>capacityProviderStrategy</code> is specified, the <code>launchType</code>
      * parameter must be omitted. If no <code>capacityProviderStrategy</code> or
      * <code>launchType</code> is specified, the
-     * <code>defaultCapacityProviderStrategy</code> for the cluster is used.</p> <p>If
-     * specifying a capacity provider that uses an Auto Scaling group, the capacity
-     * provider must already be created. New capacity providers can be created with the
-     * <a>CreateCapacityProvider</a> API operation.</p> <p>To use a AWS Fargate
-     * capacity provider, specify either the <code>FARGATE</code> or
-     * <code>FARGATE_SPOT</code> capacity providers. The AWS Fargate capacity providers
-     * are available to all accounts and only need to be associated with a cluster to
-     * be used.</p> <p>The <a>PutClusterCapacityProviders</a> API operation is used to
-     * update the list of available capacity providers for a cluster after the cluster
-     * is created.</p>
+     * <code>defaultCapacityProviderStrategy</code> for the cluster is used.</p>
      */
     inline RunTaskRequest& AddCapacityProviderStrategy(CapacityProviderStrategyItem&& value) { m_capacityProviderStrategyHasBeenSet = true; m_capacityProviderStrategy.push_back(std::move(value)); return *this; }
 
@@ -365,6 +235,35 @@ namespace Model
     inline RunTaskRequest& WithEnableECSManagedTags(bool value) { SetEnableECSManagedTags(value); return *this;}
 
 
+    /**
+     * <p>Whether or not to enable the execute command functionality for the containers
+     * in this task. If <code>true</code>, this enables execute command functionality
+     * on all containers in the task.</p>
+     */
+    inline bool GetEnableExecuteCommand() const{ return m_enableExecuteCommand; }
+
+    /**
+     * <p>Whether or not to enable the execute command functionality for the containers
+     * in this task. If <code>true</code>, this enables execute command functionality
+     * on all containers in the task.</p>
+     */
+    inline bool EnableExecuteCommandHasBeenSet() const { return m_enableExecuteCommandHasBeenSet; }
+
+    /**
+     * <p>Whether or not to enable the execute command functionality for the containers
+     * in this task. If <code>true</code>, this enables execute command functionality
+     * on all containers in the task.</p>
+     */
+    inline void SetEnableExecuteCommand(bool value) { m_enableExecuteCommandHasBeenSet = true; m_enableExecuteCommand = value; }
+
+    /**
+     * <p>Whether or not to enable the execute command functionality for the containers
+     * in this task. If <code>true</code>, this enables execute command functionality
+     * on all containers in the task.</p>
+     */
+    inline RunTaskRequest& WithEnableExecuteCommand(bool value) { SetEnableExecuteCommand(value); return *this;}
+
+
     /**
      * <p>The name of the task group to associate with the task. The default value is
      * the family name of the task definition (for example, family:my-family-name).</p>
@@ -415,55 +314,91 @@ namespace Model
 
 
     /**
-     * <p>The launch type on which to run your task. For more information, see <a
+     * <p>The launch type on which to run your task. The accepted values are
+     * <code>FARGATE</code> and <code>EC2</code>. For more information, see <a
      * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/launch_types.html">Amazon
      * ECS Launch Types</a> in the <i>Amazon Elastic Container Service Developer
-     * Guide</i>.</p> <p>If a <code>launchType</code> is specified, the
+     * Guide</i>.</p> <p>When a value of <code>FARGATE</code> is specified, your tasks
+     * are launched on AWS Fargate On-Demand infrastructure. To use Fargate Spot, you
+     * must use a capacity provider strategy with the <code>FARGATE_SPOT</code>
+     * capacity provider.</p> <p>When a value of <code>EC2</code> is specified, your
+     * tasks are launched on Amazon EC2 instances registered to your cluster.</p> <p>If
+     * a <code>launchType</code> is specified, the
      * <code>capacityProviderStrategy</code> parameter must be omitted.</p>
      */
     inline const LaunchType& GetLaunchType() const{ return m_launchType; }
 
     /**
-     * <p>The launch type on which to run your task. For more information, see <a
+     * <p>The launch type on which to run your task. The accepted values are
+     * <code>FARGATE</code> and <code>EC2</code>. For more information, see <a
      * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/launch_types.html">Amazon
      * ECS Launch Types</a> in the <i>Amazon Elastic Container Service Developer
-     * Guide</i>.</p> <p>If a <code>launchType</code> is specified, the
+     * Guide</i>.</p> <p>When a value of <code>FARGATE</code> is specified, your tasks
+     * are launched on AWS Fargate On-Demand infrastructure. To use Fargate Spot, you
+     * must use a capacity provider strategy with the <code>FARGATE_SPOT</code>
+     * capacity provider.</p> <p>When a value of <code>EC2</code> is specified, your
+     * tasks are launched on Amazon EC2 instances registered to your cluster.</p> <p>If
+     * a <code>launchType</code> is specified, the
      * <code>capacityProviderStrategy</code> parameter must be omitted.</p>
      */
     inline bool LaunchTypeHasBeenSet() const { return m_launchTypeHasBeenSet; }
 
     /**
-     * <p>The launch type on which to run your task. For more information, see <a
+     * <p>The launch type on which to run your task. The accepted values are
+     * <code>FARGATE</code> and <code>EC2</code>. For more information, see <a
      * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/launch_types.html">Amazon
      * ECS Launch Types</a> in the <i>Amazon Elastic Container Service Developer
-     * Guide</i>.</p> <p>If a <code>launchType</code> is specified, the
+     * Guide</i>.</p> <p>When a value of <code>FARGATE</code> is specified, your tasks
+     * are launched on AWS Fargate On-Demand infrastructure. To use Fargate Spot, you
+     * must use a capacity provider strategy with the <code>FARGATE_SPOT</code>
+     * capacity provider.</p> <p>When a value of <code>EC2</code> is specified, your
+     * tasks are launched on Amazon EC2 instances registered to your cluster.</p> <p>If
+     * a <code>launchType</code> is specified, the
      * <code>capacityProviderStrategy</code> parameter must be omitted.</p>
      */
     inline void SetLaunchType(const LaunchType& value) { m_launchTypeHasBeenSet = true; m_launchType = value; }
 
     /**
-     * <p>The launch type on which to run your task. For more information, see <a
+     * <p>The launch type on which to run your task. The accepted values are
+     * <code>FARGATE</code> and <code>EC2</code>. For more information, see <a
      * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/launch_types.html">Amazon
      * ECS Launch Types</a> in the <i>Amazon Elastic Container Service Developer
-     * Guide</i>.</p> <p>If a <code>launchType</code> is specified, the
+     * Guide</i>.</p> <p>When a value of <code>FARGATE</code> is specified, your tasks
+     * are launched on AWS Fargate On-Demand infrastructure. To use Fargate Spot, you
+     * must use a capacity provider strategy with the <code>FARGATE_SPOT</code>
+     * capacity provider.</p> <p>When a value of <code>EC2</code> is specified, your
+     * tasks are launched on Amazon EC2 instances registered to your cluster.</p> <p>If
+     * a <code>launchType</code> is specified, the
      * <code>capacityProviderStrategy</code> parameter must be omitted.</p>
      */
     inline void SetLaunchType(LaunchType&& value) { m_launchTypeHasBeenSet = true; m_launchType = std::move(value); }
 
     /**
-     * <p>The launch type on which to run your task. For more information, see <a
+     * <p>The launch type on which to run your task. The accepted values are
+     * <code>FARGATE</code> and <code>EC2</code>. For more information, see <a
      * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/launch_types.html">Amazon
      * ECS Launch Types</a> in the <i>Amazon Elastic Container Service Developer
-     * Guide</i>.</p> <p>If a <code>launchType</code> is specified, the
+     * Guide</i>.</p> <p>When a value of <code>FARGATE</code> is specified, your tasks
+     * are launched on AWS Fargate On-Demand infrastructure. To use Fargate Spot, you
+     * must use a capacity provider strategy with the <code>FARGATE_SPOT</code>
+     * capacity provider.</p> <p>When a value of <code>EC2</code> is specified, your
+     * tasks are launched on Amazon EC2 instances registered to your cluster.</p> <p>If
+     * a <code>launchType</code> is specified, the
      * <code>capacityProviderStrategy</code> parameter must be omitted.</p>
      */
     inline RunTaskRequest& WithLaunchType(const LaunchType& value) { SetLaunchType(value); return *this;}
 
     /**
-     * <p>The launch type on which to run your task. For more information, see <a
+     * <p>The launch type on which to run your task. The accepted values are
+     * <code>FARGATE</code> and <code>EC2</code>. For more information, see <a
      * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/launch_types.html">Amazon
      * ECS Launch Types</a> in the <i>Amazon Elastic Container Service Developer
-     * Guide</i>.</p> <p>If a <code>launchType</code> is specified, the
+     * Guide</i>.</p> <p>When a value of <code>FARGATE</code> is specified, your tasks
+     * are launched on AWS Fargate On-Demand infrastructure. To use Fargate Spot, you
+     * must use a capacity provider strategy with the <code>FARGATE_SPOT</code>
+     * capacity provider.</p> <p>When a value of <code>EC2</code> is specified, your
+     * tasks are launched on Amazon EC2 instances registered to your cluster.</p> <p>If
+     * a <code>launchType</code> is specified, the
      * <code>capacityProviderStrategy</code> parameter must be omitted.</p>
      */
     inline RunTaskRequest& WithLaunchType(LaunchType&& value) { SetLaunchType(std::move(value)); return *this;}
@@ -543,9 +478,9 @@ namespace Model
      * task definition or Docker image) with a <code>command</code> override. You can
      * also override existing environment variables (that are specified in the task
      * definition or Docker image) on a container or add new environment variables to
-     * it with an <code>environment</code> override.</p> <note> <p>A total of 8192
+     * it with an <code>environment</code> override.</p>  <p>A total of 8192
      * characters are allowed for overrides. This limit includes the JSON formatting
-     * characters of the override structure.</p> </note>
+     * characters of the override structure.</p> 
      */
     inline const TaskOverride& GetOverrides() const{ return m_overrides; }
 
@@ -556,9 +491,9 @@ namespace Model
      * task definition or Docker image) with a <code>command</code> override. You can
      * also override existing environment variables (that are specified in the task
      * definition or Docker image) on a container or add new environment variables to
-     * it with an <code>environment</code> override.</p> <note> <p>A total of 8192
+     * it with an <code>environment</code> override.</p>  <p>A total of 8192
      * characters are allowed for overrides. This limit includes the JSON formatting
-     * characters of the override structure.</p> </note>
+     * characters of the override structure.</p> 
      */
     inline bool OverridesHasBeenSet() const { return m_overridesHasBeenSet; }
 
@@ -569,9 +504,9 @@ namespace Model
      * task definition or Docker image) with a <code>command</code> override. You can
      * also override existing environment variables (that are specified in the task
      * definition or Docker image) on a container or add new environment variables to
-     * it with an <code>environment</code> override.</p> <note> <p>A total of 8192
+     * it with an <code>environment</code> override.</p>  <p>A total of 8192
      * characters are allowed for overrides. This limit includes the JSON formatting
-     * characters of the override structure.</p> </note>
+     * characters of the override structure.</p> 
      */
     inline void SetOverrides(const TaskOverride& value) { m_overridesHasBeenSet = true; m_overrides = value; }
 
@@ -582,9 +517,9 @@ namespace Model
      * task definition or Docker image) with a <code>command</code> override. You can
      * also override existing environment variables (that are specified in the task
      * definition or Docker image) on a container or add new environment variables to
-     * it with an <code>environment</code> override.</p> <note> <p>A total of 8192
+     * it with an <code>environment</code> override.</p>  <p>A total of 8192
      * characters are allowed for overrides. This limit includes the JSON formatting
-     * characters of the override structure.</p> </note>
+     * characters of the override structure.</p> 
      */
     inline void SetOverrides(TaskOverride&& value) { m_overridesHasBeenSet = true; m_overrides = std::move(value); }
 
@@ -595,9 +530,9 @@ namespace Model
      * task definition or Docker image) with a <code>command</code> override. You can
      * also override existing environment variables (that are specified in the task
      * definition or Docker image) on a container or add new environment variables to
-     * it with an <code>environment</code> override.</p> <note> <p>A total of 8192
+     * it with an <code>environment</code> override.</p>  <p>A total of 8192
      * characters are allowed for overrides. This limit includes the JSON formatting
-     * characters of the override structure.</p> </note>
+     * characters of the override structure.</p> 
      */
     inline RunTaskRequest& WithOverrides(const TaskOverride& value) { SetOverrides(value); return *this;}
 
@@ -608,9 +543,9 @@ namespace Model
      * task definition or Docker image) with a <code>command</code> override. You can
      * also override existing environment variables (that are specified in the task
      * definition or Docker image) on a container or add new environment variables to
-     * it with an <code>environment</code> override.</p> <note> <p>A total of 8192
+     * it with an <code>environment</code> override.</p>  <p>A total of 8192
      * characters are allowed for overrides. This limit includes the JSON formatting
-     * characters of the override structure.</p> </note>
+     * characters of the override structure.</p> 
      */
     inline RunTaskRequest& WithOverrides(TaskOverride&& value) { SetOverrides(std::move(value)); return *this;}
 
@@ -814,9 +749,9 @@ namespace Model
      * <p>Specifies whether to propagate the tags from the task definition to the task.
      * If no value is specified, the tags are not propagated. Tags can only be
      * propagated to the task during task creation. To add tags to a task after task
-     * creation, use the <a>TagResource</a> API action.</p> <note> <p>An error will be
+     * creation, use the <a>TagResource</a> API action.</p>  <p>An error will be
      * received if you specify the <code>SERVICE</code> option when running a task.</p>
-     * </note>
+     * 
      */
     inline const PropagateTags& GetPropagateTags() const{ return m_propagateTags; }
 
@@ -824,9 +759,9 @@ namespace Model
      * <p>Specifies whether to propagate the tags from the task definition to the task.
      * If no value is specified, the tags are not propagated. Tags can only be
      * propagated to the task during task creation. To add tags to a task after task
-     * creation, use the <a>TagResource</a> API action.</p> <note> <p>An error will be
+     * creation, use the <a>TagResource</a> API action.</p>  <p>An error will be
      * received if you specify the <code>SERVICE</code> option when running a task.</p>
-     * </note>
+     * 
      */
     inline bool PropagateTagsHasBeenSet() const { return m_propagateTagsHasBeenSet; }
 
@@ -834,9 +769,9 @@ namespace Model
      * <p>Specifies whether to propagate the tags from the task definition to the task.
      * If no value is specified, the tags are not propagated. Tags can only be
      * propagated to the task during task creation. To add tags to a task after task
-     * creation, use the <a>TagResource</a> API action.</p> <note> <p>An error will be
+     * creation, use the <a>TagResource</a> API action.</p>  <p>An error will be
      * received if you specify the <code>SERVICE</code> option when running a task.</p>
-     * </note>
+     * 
      */
     inline void SetPropagateTags(const PropagateTags& value) { m_propagateTagsHasBeenSet = true; m_propagateTags = value; }
 
@@ -844,9 +779,9 @@ namespace Model
      * <p>Specifies whether to propagate the tags from the task definition to the task.
      * If no value is specified, the tags are not propagated. Tags can only be
      * propagated to the task during task creation. To add tags to a task after task
-     * creation, use the <a>TagResource</a> API action.</p> <note> <p>An error will be
+     * creation, use the <a>TagResource</a> API action.</p>  <p>An error will be
      * received if you specify the <code>SERVICE</code> option when running a task.</p>
-     * </note>
+     * 
      */
     inline void SetPropagateTags(PropagateTags&& value) { m_propagateTagsHasBeenSet = true; m_propagateTags = std::move(value); }
 
@@ -854,9 +789,9 @@ namespace Model
      * <p>Specifies whether to propagate the tags from the task definition to the task.
      * If no value is specified, the tags are not propagated. Tags can only be
      * propagated to the task during task creation. To add tags to a task after task
-     * creation, use the <a>TagResource</a> API action.</p> <note> <p>An error will be
+     * creation, use the <a>TagResource</a> API action.</p>  <p>An error will be
      * received if you specify the <code>SERVICE</code> option when running a task.</p>
-     * </note>
+     * 
      */
     inline RunTaskRequest& WithPropagateTags(const PropagateTags& value) { SetPropagateTags(value); return *this;}
 
@@ -864,9 +799,9 @@ namespace Model
      * <p>Specifies whether to propagate the tags from the task definition to the task.
      * If no value is specified, the tags are not propagated. Tags can only be
      * propagated to the task during task creation. To add tags to a task after task
-     * creation, use the <a>TagResource</a> API action.</p> <note> <p>An error will be
+     * creation, use the <a>TagResource</a> API action.</p>  <p>An error will be
      * received if you specify the <code>SERVICE</code> option when running a task.</p>
-     * </note>
+     * 
      */
     inline RunTaskRequest& WithPropagateTags(PropagateTags&& value) { SetPropagateTags(std::move(value)); return *this;}
 
@@ -1256,6 +1191,9 @@ namespace Model
     bool m_enableECSManagedTags;
     bool m_enableECSManagedTagsHasBeenSet;
 
+    bool m_enableExecuteCommand;
+    bool m_enableExecuteCommandHasBeenSet;
+
     Aws::String m_group;
     bool m_groupHasBeenSet;
 
