@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/events/CloudWatchEvents_EXPORTS.h>
@@ -46,99 +36,99 @@ namespace Model
 
 
     /**
-     * <p>The event bus associated with the rule. If you omit this, the default event
-     * bus is used.</p>
+     * <p>The name of the event bus associated with the rule. If you omit this, the
+     * default event bus is used.</p>
      */
     inline const Aws::String& GetEventBusName() const{ return m_eventBusName; }
 
     /**
-     * <p>The event bus associated with the rule. If you omit this, the default event
-     * bus is used.</p>
+     * <p>The name of the event bus associated with the rule. If you omit this, the
+     * default event bus is used.</p>
      */
     inline bool EventBusNameHasBeenSet() const { return m_eventBusNameHasBeenSet; }
 
     /**
-     * <p>The event bus associated with the rule. If you omit this, the default event
-     * bus is used.</p>
+     * <p>The name of the event bus associated with the rule. If you omit this, the
+     * default event bus is used.</p>
      */
     inline void SetEventBusName(const Aws::String& value) { m_eventBusNameHasBeenSet = true; m_eventBusName = value; }
 
     /**
-     * <p>The event bus associated with the rule. If you omit this, the default event
-     * bus is used.</p>
+     * <p>The name of the event bus associated with the rule. If you omit this, the
+     * default event bus is used.</p>
      */
     inline void SetEventBusName(Aws::String&& value) { m_eventBusNameHasBeenSet = true; m_eventBusName = std::move(value); }
 
     /**
-     * <p>The event bus associated with the rule. If you omit this, the default event
-     * bus is used.</p>
+     * <p>The name of the event bus associated with the rule. If you omit this, the
+     * default event bus is used.</p>
      */
     inline void SetEventBusName(const char* value) { m_eventBusNameHasBeenSet = true; m_eventBusName.assign(value); }
 
     /**
-     * <p>The event bus associated with the rule. If you omit this, the default event
-     * bus is used.</p>
+     * <p>The name of the event bus associated with the rule. If you omit this, the
+     * default event bus is used.</p>
      */
     inline PutPermissionRequest& WithEventBusName(const Aws::String& value) { SetEventBusName(value); return *this;}
 
     /**
-     * <p>The event bus associated with the rule. If you omit this, the default event
-     * bus is used.</p>
+     * <p>The name of the event bus associated with the rule. If you omit this, the
+     * default event bus is used.</p>
      */
     inline PutPermissionRequest& WithEventBusName(Aws::String&& value) { SetEventBusName(std::move(value)); return *this;}
 
     /**
-     * <p>The event bus associated with the rule. If you omit this, the default event
-     * bus is used.</p>
+     * <p>The name of the event bus associated with the rule. If you omit this, the
+     * default event bus is used.</p>
      */
     inline PutPermissionRequest& WithEventBusName(const char* value) { SetEventBusName(value); return *this;}
 
 
     /**
-     * <p>The action that you're enabling the other account to perform. Currently, this
-     * must be <code>events:PutEvents</code>.</p>
+     * <p>The action that you are enabling the other account to perform. Currently,
+     * this must be <code>events:PutEvents</code>.</p>
      */
     inline const Aws::String& GetAction() const{ return m_action; }
 
     /**
-     * <p>The action that you're enabling the other account to perform. Currently, this
-     * must be <code>events:PutEvents</code>.</p>
+     * <p>The action that you are enabling the other account to perform. Currently,
+     * this must be <code>events:PutEvents</code>.</p>
      */
     inline bool ActionHasBeenSet() const { return m_actionHasBeenSet; }
 
     /**
-     * <p>The action that you're enabling the other account to perform. Currently, this
-     * must be <code>events:PutEvents</code>.</p>
+     * <p>The action that you are enabling the other account to perform. Currently,
+     * this must be <code>events:PutEvents</code>.</p>
      */
     inline void SetAction(const Aws::String& value) { m_actionHasBeenSet = true; m_action = value; }
 
     /**
-     * <p>The action that you're enabling the other account to perform. Currently, this
-     * must be <code>events:PutEvents</code>.</p>
+     * <p>The action that you are enabling the other account to perform. Currently,
+     * this must be <code>events:PutEvents</code>.</p>
      */
     inline void SetAction(Aws::String&& value) { m_actionHasBeenSet = true; m_action = std::move(value); }
 
     /**
-     * <p>The action that you're enabling the other account to perform. Currently, this
-     * must be <code>events:PutEvents</code>.</p>
+     * <p>The action that you are enabling the other account to perform. Currently,
+     * this must be <code>events:PutEvents</code>.</p>
      */
     inline void SetAction(const char* value) { m_actionHasBeenSet = true; m_action.assign(value); }
 
     /**
-     * <p>The action that you're enabling the other account to perform. Currently, this
-     * must be <code>events:PutEvents</code>.</p>
+     * <p>The action that you are enabling the other account to perform. Currently,
+     * this must be <code>events:PutEvents</code>.</p>
      */
     inline PutPermissionRequest& WithAction(const Aws::String& value) { SetAction(value); return *this;}
 
     /**
-     * <p>The action that you're enabling the other account to perform. Currently, this
-     * must be <code>events:PutEvents</code>.</p>
+     * <p>The action that you are enabling the other account to perform. Currently,
+     * this must be <code>events:PutEvents</code>.</p>
      */
     inline PutPermissionRequest& WithAction(Aws::String&& value) { SetAction(std::move(value)); return *this;}
 
     /**
-     * <p>The action that you're enabling the other account to perform. Currently, this
-     * must be <code>events:PutEvents</code>.</p>
+     * <p>The action that you are enabling the other account to perform. Currently,
+     * this must be <code>events:PutEvents</code>.</p>
      */
     inline PutPermissionRequest& WithAction(const char* value) { SetAction(value); return *this;}
 
@@ -147,11 +137,11 @@ namespace Model
      * <p>The 12-digit AWS account ID that you are permitting to put events to your
      * default event bus. Specify "*" to permit any account to put events to your
      * default event bus.</p> <p>If you specify "*" without specifying
-     * <code>Condition</code>, avoid creating rules that might match undesirable
-     * events. To create more secure rules, make sure that the event pattern for each
-     * rule contains an <code>account</code> field with a specific account ID to
-     * receive events from. Rules with an account field don't match any events sent
-     * from other accounts.</p>
+     * <code>Condition</code>, avoid creating rules that may match undesirable events.
+     * To create more secure rules, make sure that the event pattern for each rule
+     * contains an <code>account</code> field with a specific account ID from which to
+     * receive events. Rules with an account field do not match any events sent from
+     * other accounts.</p>
      */
     inline const Aws::String& GetPrincipal() const{ return m_principal; }
 
@@ -159,11 +149,11 @@ namespace Model
      * <p>The 12-digit AWS account ID that you are permitting to put events to your
      * default event bus. Specify "*" to permit any account to put events to your
      * default event bus.</p> <p>If you specify "*" without specifying
-     * <code>Condition</code>, avoid creating rules that might match undesirable
-     * events. To create more secure rules, make sure that the event pattern for each
-     * rule contains an <code>account</code> field with a specific account ID to
-     * receive events from. Rules with an account field don't match any events sent
-     * from other accounts.</p>
+     * <code>Condition</code>, avoid creating rules that may match undesirable events.
+     * To create more secure rules, make sure that the event pattern for each rule
+     * contains an <code>account</code> field with a specific account ID from which to
+     * receive events. Rules with an account field do not match any events sent from
+     * other accounts.</p>
      */
     inline bool PrincipalHasBeenSet() const { return m_principalHasBeenSet; }
 
@@ -171,11 +161,11 @@ namespace Model
      * <p>The 12-digit AWS account ID that you are permitting to put events to your
      * default event bus. Specify "*" to permit any account to put events to your
      * default event bus.</p> <p>If you specify "*" without specifying
-     * <code>Condition</code>, avoid creating rules that might match undesirable
-     * events. To create more secure rules, make sure that the event pattern for each
-     * rule contains an <code>account</code> field with a specific account ID to
-     * receive events from. Rules with an account field don't match any events sent
-     * from other accounts.</p>
+     * <code>Condition</code>, avoid creating rules that may match undesirable events.
+     * To create more secure rules, make sure that the event pattern for each rule
+     * contains an <code>account</code> field with a specific account ID from which to
+     * receive events. Rules with an account field do not match any events sent from
+     * other accounts.</p>
      */
     inline void SetPrincipal(const Aws::String& value) { m_principalHasBeenSet = true; m_principal = value; }
 
@@ -183,11 +173,11 @@ namespace Model
      * <p>The 12-digit AWS account ID that you are permitting to put events to your
      * default event bus. Specify "*" to permit any account to put events to your
      * default event bus.</p> <p>If you specify "*" without specifying
-     * <code>Condition</code>, avoid creating rules that might match undesirable
-     * events. To create more secure rules, make sure that the event pattern for each
-     * rule contains an <code>account</code> field with a specific account ID to
-     * receive events from. Rules with an account field don't match any events sent
-     * from other accounts.</p>
+     * <code>Condition</code>, avoid creating rules that may match undesirable events.
+     * To create more secure rules, make sure that the event pattern for each rule
+     * contains an <code>account</code> field with a specific account ID from which to
+     * receive events. Rules with an account field do not match any events sent from
+     * other accounts.</p>
      */
     inline void SetPrincipal(Aws::String&& value) { m_principalHasBeenSet = true; m_principal = std::move(value); }
 
@@ -195,11 +185,11 @@ namespace Model
      * <p>The 12-digit AWS account ID that you are permitting to put events to your
      * default event bus. Specify "*" to permit any account to put events to your
      * default event bus.</p> <p>If you specify "*" without specifying
-     * <code>Condition</code>, avoid creating rules that might match undesirable
-     * events. To create more secure rules, make sure that the event pattern for each
-     * rule contains an <code>account</code> field with a specific account ID to
-     * receive events from. Rules with an account field don't match any events sent
-     * from other accounts.</p>
+     * <code>Condition</code>, avoid creating rules that may match undesirable events.
+     * To create more secure rules, make sure that the event pattern for each rule
+     * contains an <code>account</code> field with a specific account ID from which to
+     * receive events. Rules with an account field do not match any events sent from
+     * other accounts.</p>
      */
     inline void SetPrincipal(const char* value) { m_principalHasBeenSet = true; m_principal.assign(value); }
 
@@ -207,11 +197,11 @@ namespace Model
      * <p>The 12-digit AWS account ID that you are permitting to put events to your
      * default event bus. Specify "*" to permit any account to put events to your
      * default event bus.</p> <p>If you specify "*" without specifying
-     * <code>Condition</code>, avoid creating rules that might match undesirable
-     * events. To create more secure rules, make sure that the event pattern for each
-     * rule contains an <code>account</code> field with a specific account ID to
-     * receive events from. Rules with an account field don't match any events sent
-     * from other accounts.</p>
+     * <code>Condition</code>, avoid creating rules that may match undesirable events.
+     * To create more secure rules, make sure that the event pattern for each rule
+     * contains an <code>account</code> field with a specific account ID from which to
+     * receive events. Rules with an account field do not match any events sent from
+     * other accounts.</p>
      */
     inline PutPermissionRequest& WithPrincipal(const Aws::String& value) { SetPrincipal(value); return *this;}
 
@@ -219,11 +209,11 @@ namespace Model
      * <p>The 12-digit AWS account ID that you are permitting to put events to your
      * default event bus. Specify "*" to permit any account to put events to your
      * default event bus.</p> <p>If you specify "*" without specifying
-     * <code>Condition</code>, avoid creating rules that might match undesirable
-     * events. To create more secure rules, make sure that the event pattern for each
-     * rule contains an <code>account</code> field with a specific account ID to
-     * receive events from. Rules with an account field don't match any events sent
-     * from other accounts.</p>
+     * <code>Condition</code>, avoid creating rules that may match undesirable events.
+     * To create more secure rules, make sure that the event pattern for each rule
+     * contains an <code>account</code> field with a specific account ID from which to
+     * receive events. Rules with an account field do not match any events sent from
+     * other accounts.</p>
      */
     inline PutPermissionRequest& WithPrincipal(Aws::String&& value) { SetPrincipal(std::move(value)); return *this;}
 
@@ -231,17 +221,17 @@ namespace Model
      * <p>The 12-digit AWS account ID that you are permitting to put events to your
      * default event bus. Specify "*" to permit any account to put events to your
      * default event bus.</p> <p>If you specify "*" without specifying
-     * <code>Condition</code>, avoid creating rules that might match undesirable
-     * events. To create more secure rules, make sure that the event pattern for each
-     * rule contains an <code>account</code> field with a specific account ID to
-     * receive events from. Rules with an account field don't match any events sent
-     * from other accounts.</p>
+     * <code>Condition</code>, avoid creating rules that may match undesirable events.
+     * To create more secure rules, make sure that the event pattern for each rule
+     * contains an <code>account</code> field with a specific account ID from which to
+     * receive events. Rules with an account field do not match any events sent from
+     * other accounts.</p>
      */
     inline PutPermissionRequest& WithPrincipal(const char* value) { SetPrincipal(value); return *this;}
 
 
     /**
-     * <p>An identifier string for the external account that you're granting
+     * <p>An identifier string for the external account that you are granting
      * permissions to. If you later want to revoke the permission for this external
      * account, specify this <code>StatementId</code> when you run
      * <a>RemovePermission</a>.</p>
@@ -249,7 +239,7 @@ namespace Model
     inline const Aws::String& GetStatementId() const{ return m_statementId; }
 
     /**
-     * <p>An identifier string for the external account that you're granting
+     * <p>An identifier string for the external account that you are granting
      * permissions to. If you later want to revoke the permission for this external
      * account, specify this <code>StatementId</code> when you run
      * <a>RemovePermission</a>.</p>
@@ -257,7 +247,7 @@ namespace Model
     inline bool StatementIdHasBeenSet() const { return m_statementIdHasBeenSet; }
 
     /**
-     * <p>An identifier string for the external account that you're granting
+     * <p>An identifier string for the external account that you are granting
      * permissions to. If you later want to revoke the permission for this external
      * account, specify this <code>StatementId</code> when you run
      * <a>RemovePermission</a>.</p>
@@ -265,7 +255,7 @@ namespace Model
     inline void SetStatementId(const Aws::String& value) { m_statementIdHasBeenSet = true; m_statementId = value; }
 
     /**
-     * <p>An identifier string for the external account that you're granting
+     * <p>An identifier string for the external account that you are granting
      * permissions to. If you later want to revoke the permission for this external
      * account, specify this <code>StatementId</code> when you run
      * <a>RemovePermission</a>.</p>
@@ -273,7 +263,7 @@ namespace Model
     inline void SetStatementId(Aws::String&& value) { m_statementIdHasBeenSet = true; m_statementId = std::move(value); }
 
     /**
-     * <p>An identifier string for the external account that you're granting
+     * <p>An identifier string for the external account that you are granting
      * permissions to. If you later want to revoke the permission for this external
      * account, specify this <code>StatementId</code> when you run
      * <a>RemovePermission</a>.</p>
@@ -281,7 +271,7 @@ namespace Model
     inline void SetStatementId(const char* value) { m_statementIdHasBeenSet = true; m_statementId.assign(value); }
 
     /**
-     * <p>An identifier string for the external account that you're granting
+     * <p>An identifier string for the external account that you are granting
      * permissions to. If you later want to revoke the permission for this external
      * account, specify this <code>StatementId</code> when you run
      * <a>RemovePermission</a>.</p>
@@ -289,7 +279,7 @@ namespace Model
     inline PutPermissionRequest& WithStatementId(const Aws::String& value) { SetStatementId(value); return *this;}
 
     /**
-     * <p>An identifier string for the external account that you're granting
+     * <p>An identifier string for the external account that you are granting
      * permissions to. If you later want to revoke the permission for this external
      * account, specify this <code>StatementId</code> when you run
      * <a>RemovePermission</a>.</p>
@@ -297,7 +287,7 @@ namespace Model
     inline PutPermissionRequest& WithStatementId(Aws::String&& value) { SetStatementId(std::move(value)); return *this;}
 
     /**
-     * <p>An identifier string for the external account that you're granting
+     * <p>An identifier string for the external account that you are granting
      * permissions to. If you later want to revoke the permission for this external
      * account, specify this <code>StatementId</code> when you run
      * <a>RemovePermission</a>.</p>
@@ -310,11 +300,11 @@ namespace Model
      * certain condition, such as being a member of a certain AWS organization. For
      * more information about AWS Organizations, see <a
      * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_introduction.html">What
-     * Is AWS Organizations?</a> in the <i>AWS Organizations User Guide</i>.</p> <p>If
-     * you specify <code>Condition</code> with an AWS organization ID and specify "*"
+     * Is AWS Organizations</a> in the <i>AWS Organizations User Guide</i>.</p> <p>If
+     * you specify <code>Condition</code> with an AWS organization ID, and specify "*"
      * as the value for <code>Principal</code>, you grant permission to all the
      * accounts in the named organization.</p> <p>The <code>Condition</code> is a JSON
-     * string that must contain <code>Type</code>, <code>Key</code>, and
+     * string which must contain <code>Type</code>, <code>Key</code>, and
      * <code>Value</code> fields.</p>
      */
     inline const Condition& GetCondition() const{ return m_condition; }
@@ -324,11 +314,11 @@ namespace Model
      * certain condition, such as being a member of a certain AWS organization. For
      * more information about AWS Organizations, see <a
      * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_introduction.html">What
-     * Is AWS Organizations?</a> in the <i>AWS Organizations User Guide</i>.</p> <p>If
-     * you specify <code>Condition</code> with an AWS organization ID and specify "*"
+     * Is AWS Organizations</a> in the <i>AWS Organizations User Guide</i>.</p> <p>If
+     * you specify <code>Condition</code> with an AWS organization ID, and specify "*"
      * as the value for <code>Principal</code>, you grant permission to all the
      * accounts in the named organization.</p> <p>The <code>Condition</code> is a JSON
-     * string that must contain <code>Type</code>, <code>Key</code>, and
+     * string which must contain <code>Type</code>, <code>Key</code>, and
      * <code>Value</code> fields.</p>
      */
     inline bool ConditionHasBeenSet() const { return m_conditionHasBeenSet; }
@@ -338,11 +328,11 @@ namespace Model
      * certain condition, such as being a member of a certain AWS organization. For
      * more information about AWS Organizations, see <a
      * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_introduction.html">What
-     * Is AWS Organizations?</a> in the <i>AWS Organizations User Guide</i>.</p> <p>If
-     * you specify <code>Condition</code> with an AWS organization ID and specify "*"
+     * Is AWS Organizations</a> in the <i>AWS Organizations User Guide</i>.</p> <p>If
+     * you specify <code>Condition</code> with an AWS organization ID, and specify "*"
      * as the value for <code>Principal</code>, you grant permission to all the
      * accounts in the named organization.</p> <p>The <code>Condition</code> is a JSON
-     * string that must contain <code>Type</code>, <code>Key</code>, and
+     * string which must contain <code>Type</code>, <code>Key</code>, and
      * <code>Value</code> fields.</p>
      */
     inline void SetCondition(const Condition& value) { m_conditionHasBeenSet = true; m_condition = value; }
@@ -352,11 +342,11 @@ namespace Model
      * certain condition, such as being a member of a certain AWS organization. For
      * more information about AWS Organizations, see <a
      * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_introduction.html">What
-     * Is AWS Organizations?</a> in the <i>AWS Organizations User Guide</i>.</p> <p>If
-     * you specify <code>Condition</code> with an AWS organization ID and specify "*"
+     * Is AWS Organizations</a> in the <i>AWS Organizations User Guide</i>.</p> <p>If
+     * you specify <code>Condition</code> with an AWS organization ID, and specify "*"
      * as the value for <code>Principal</code>, you grant permission to all the
      * accounts in the named organization.</p> <p>The <code>Condition</code> is a JSON
-     * string that must contain <code>Type</code>, <code>Key</code>, and
+     * string which must contain <code>Type</code>, <code>Key</code>, and
      * <code>Value</code> fields.</p>
      */
     inline void SetCondition(Condition&& value) { m_conditionHasBeenSet = true; m_condition = std::move(value); }
@@ -366,11 +356,11 @@ namespace Model
      * certain condition, such as being a member of a certain AWS organization. For
      * more information about AWS Organizations, see <a
      * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_introduction.html">What
-     * Is AWS Organizations?</a> in the <i>AWS Organizations User Guide</i>.</p> <p>If
-     * you specify <code>Condition</code> with an AWS organization ID and specify "*"
+     * Is AWS Organizations</a> in the <i>AWS Organizations User Guide</i>.</p> <p>If
+     * you specify <code>Condition</code> with an AWS organization ID, and specify "*"
      * as the value for <code>Principal</code>, you grant permission to all the
      * accounts in the named organization.</p> <p>The <code>Condition</code> is a JSON
-     * string that must contain <code>Type</code>, <code>Key</code>, and
+     * string which must contain <code>Type</code>, <code>Key</code>, and
      * <code>Value</code> fields.</p>
      */
     inline PutPermissionRequest& WithCondition(const Condition& value) { SetCondition(value); return *this;}
@@ -380,15 +370,80 @@ namespace Model
      * certain condition, such as being a member of a certain AWS organization. For
      * more information about AWS Organizations, see <a
      * href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_introduction.html">What
-     * Is AWS Organizations?</a> in the <i>AWS Organizations User Guide</i>.</p> <p>If
-     * you specify <code>Condition</code> with an AWS organization ID and specify "*"
+     * Is AWS Organizations</a> in the <i>AWS Organizations User Guide</i>.</p> <p>If
+     * you specify <code>Condition</code> with an AWS organization ID, and specify "*"
      * as the value for <code>Principal</code>, you grant permission to all the
      * accounts in the named organization.</p> <p>The <code>Condition</code> is a JSON
-     * string that must contain <code>Type</code>, <code>Key</code>, and
+     * string which must contain <code>Type</code>, <code>Key</code>, and
      * <code>Value</code> fields.</p>
      */
     inline PutPermissionRequest& WithCondition(Condition&& value) { SetCondition(std::move(value)); return *this;}
 
+
+    /**
+     * <p>A JSON string that describes the permission policy statement. You can include
+     * a <code>Policy</code> parameter in the request instead of using the
+     * <code>StatementId</code>, <code>Action</code>, <code>Principal</code>, or
+     * <code>Condition</code> parameters.</p>
+     */
+    inline const Aws::String& GetPolicy() const{ return m_policy; }
+
+    /**
+     * <p>A JSON string that describes the permission policy statement. You can include
+     * a <code>Policy</code> parameter in the request instead of using the
+     * <code>StatementId</code>, <code>Action</code>, <code>Principal</code>, or
+     * <code>Condition</code> parameters.</p>
+     */
+    inline bool PolicyHasBeenSet() const { return m_policyHasBeenSet; }
+
+    /**
+     * <p>A JSON string that describes the permission policy statement. You can include
+     * a <code>Policy</code> parameter in the request instead of using the
+     * <code>StatementId</code>, <code>Action</code>, <code>Principal</code>, or
+     * <code>Condition</code> parameters.</p>
+     */
+    inline void SetPolicy(const Aws::String& value) { m_policyHasBeenSet = true; m_policy = value; }
+
+    /**
+     * <p>A JSON string that describes the permission policy statement. You can include
+     * a <code>Policy</code> parameter in the request instead of using the
+     * <code>StatementId</code>, <code>Action</code>, <code>Principal</code>, or
+     * <code>Condition</code> parameters.</p>
+     */
+    inline void SetPolicy(Aws::String&& value) { m_policyHasBeenSet = true; m_policy = std::move(value); }
+
+    /**
+     * <p>A JSON string that describes the permission policy statement. You can include
+     * a <code>Policy</code> parameter in the request instead of using the
+     * <code>StatementId</code>, <code>Action</code>, <code>Principal</code>, or
+     * <code>Condition</code> parameters.</p>
+     */
+    inline void SetPolicy(const char* value) { m_policyHasBeenSet = true; m_policy.assign(value); }
+
+    /**
+     * <p>A JSON string that describes the permission policy statement. You can include
+     * a <code>Policy</code> parameter in the request instead of using the
+     * <code>StatementId</code>, <code>Action</code>, <code>Principal</code>, or
+     * <code>Condition</code> parameters.</p>
+     */
+    inline PutPermissionRequest& WithPolicy(const Aws::String& value) { SetPolicy(value); return *this;}
+
+    /**
+     * <p>A JSON string that describes the permission policy statement. You can include
+     * a <code>Policy</code> parameter in the request instead of using the
+     * <code>StatementId</code>, <code>Action</code>, <code>Principal</code>, or
+     * <code>Condition</code> parameters.</p>
+     */
+    inline PutPermissionRequest& WithPolicy(Aws::String&& value) { SetPolicy(std::move(value)); return *this;}
+
+    /**
+     * <p>A JSON string that describes the permission policy statement. You can include
+     * a <code>Policy</code> parameter in the request instead of using the
+     * <code>StatementId</code>, <code>Action</code>, <code>Principal</code>, or
+     * <code>Condition</code> parameters.</p>
+     */
+    inline PutPermissionRequest& WithPolicy(const char* value) { SetPolicy(value); return *this;}
+
   private:
 
     Aws::String m_eventBusName;
@@ -405,6 +460,9 @@ namespace Model
 
     Condition m_condition;
     bool m_conditionHasBeenSet;
+
+    Aws::String m_policy;
+    bool m_policyHasBeenSet;
   };
 
 } // namespace Model
