@@ -1,22 +1,13 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/imagebuilder/Imagebuilder_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/imagebuilder/model/Platform.h>
+#include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/imagebuilder/model/ComponentType.h>
 #include <aws/core/utils/memory/stl/AWSMap.h>
 #include <utility>
@@ -37,7 +28,7 @@ namespace Model
 {
 
   /**
-   * <p>A high level summary of a component.</p><p><h3>See Also:</h3>   <a
+   * <p>A high-level summary of a component.</p><p><h3>See Also:</h3>   <a
    * href="http://docs.aws.amazon.com/goto/WebAPI/imagebuilder-2019-12-02/ComponentSummary">AWS
    * API Reference</a></p>
    */
@@ -204,6 +195,70 @@ namespace Model
     inline ComponentSummary& WithPlatform(Platform&& value) { SetPlatform(std::move(value)); return *this;}
 
 
+    /**
+     * <p>The operating system (OS) version supported by the component. If the OS
+     * information is available, a prefix match is performed against the parent image
+     * OS version during image recipe creation.</p>
+     */
+    inline const Aws::Vector<Aws::String>& GetSupportedOsVersions() const{ return m_supportedOsVersions; }
+
+    /**
+     * <p>The operating system (OS) version supported by the component. If the OS
+     * information is available, a prefix match is performed against the parent image
+     * OS version during image recipe creation.</p>
+     */
+    inline bool SupportedOsVersionsHasBeenSet() const { return m_supportedOsVersionsHasBeenSet; }
+
+    /**
+     * <p>The operating system (OS) version supported by the component. If the OS
+     * information is available, a prefix match is performed against the parent image
+     * OS version during image recipe creation.</p>
+     */
+    inline void SetSupportedOsVersions(const Aws::Vector<Aws::String>& value) { m_supportedOsVersionsHasBeenSet = true; m_supportedOsVersions = value; }
+
+    /**
+     * <p>The operating system (OS) version supported by the component. If the OS
+     * information is available, a prefix match is performed against the parent image
+     * OS version during image recipe creation.</p>
+     */
+    inline void SetSupportedOsVersions(Aws::Vector<Aws::String>&& value) { m_supportedOsVersionsHasBeenSet = true; m_supportedOsVersions = std::move(value); }
+
+    /**
+     * <p>The operating system (OS) version supported by the component. If the OS
+     * information is available, a prefix match is performed against the parent image
+     * OS version during image recipe creation.</p>
+     */
+    inline ComponentSummary& WithSupportedOsVersions(const Aws::Vector<Aws::String>& value) { SetSupportedOsVersions(value); return *this;}
+
+    /**
+     * <p>The operating system (OS) version supported by the component. If the OS
+     * information is available, a prefix match is performed against the parent image
+     * OS version during image recipe creation.</p>
+     */
+    inline ComponentSummary& WithSupportedOsVersions(Aws::Vector<Aws::String>&& value) { SetSupportedOsVersions(std::move(value)); return *this;}
+
+    /**
+     * <p>The operating system (OS) version supported by the component. If the OS
+     * information is available, a prefix match is performed against the parent image
+     * OS version during image recipe creation.</p>
+     */
+    inline ComponentSummary& AddSupportedOsVersions(const Aws::String& value) { m_supportedOsVersionsHasBeenSet = true; m_supportedOsVersions.push_back(value); return *this; }
+
+    /**
+     * <p>The operating system (OS) version supported by the component. If the OS
+     * information is available, a prefix match is performed against the parent image
+     * OS version during image recipe creation.</p>
+     */
+    inline ComponentSummary& AddSupportedOsVersions(Aws::String&& value) { m_supportedOsVersionsHasBeenSet = true; m_supportedOsVersions.push_back(std::move(value)); return *this; }
+
+    /**
+     * <p>The operating system (OS) version supported by the component. If the OS
+     * information is available, a prefix match is performed against the parent image
+     * OS version during image recipe creation.</p>
+     */
+    inline ComponentSummary& AddSupportedOsVersions(const char* value) { m_supportedOsVersionsHasBeenSet = true; m_supportedOsVersions.push_back(value); return *this; }
+
+
     /**
      * <p>The type of the component denotes whether the component is used to build the
      * image or only to test it.</p>
@@ -484,6 +539,9 @@ namespace Model
     Platform m_platform;
     bool m_platformHasBeenSet;
 
+    Aws::Vector<Aws::String> m_supportedOsVersions;
+    bool m_supportedOsVersionsHasBeenSet;
+
     ComponentType m_type;
     bool m_typeHasBeenSet;
 
