@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/lambda/Lambda_EXPORTS.h>
@@ -23,6 +13,8 @@
 #include <aws/lambda/model/DeadLetterConfig.h>
 #include <aws/lambda/model/TracingConfig.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
+#include <aws/lambda/model/ImageConfig.h>
+#include <aws/lambda/model/FileSystemConfig.h>
 #include <utility>
 
 namespace Aws
@@ -326,30 +318,30 @@ namespace Model
 
 
     /**
-     * <p>The amount of memory that your function has access to. Increasing the
+     * <p>The amount of memory available to the function at runtime. Increasing the
      * function's memory also increases its CPU allocation. The default value is 128
-     * MB. The value must be a multiple of 64 MB.</p>
+     * MB. The value can be any multiple of 1 MB.</p>
      */
     inline int GetMemorySize() const{ return m_memorySize; }
 
     /**
-     * <p>The amount of memory that your function has access to. Increasing the
+     * <p>The amount of memory available to the function at runtime. Increasing the
      * function's memory also increases its CPU allocation. The default value is 128
-     * MB. The value must be a multiple of 64 MB.</p>
+     * MB. The value can be any multiple of 1 MB.</p>
      */
     inline bool MemorySizeHasBeenSet() const { return m_memorySizeHasBeenSet; }
 
     /**
-     * <p>The amount of memory that your function has access to. Increasing the
+     * <p>The amount of memory available to the function at runtime. Increasing the
      * function's memory also increases its CPU allocation. The default value is 128
-     * MB. The value must be a multiple of 64 MB.</p>
+     * MB. The value can be any multiple of 1 MB.</p>
      */
     inline void SetMemorySize(int value) { m_memorySizeHasBeenSet = true; m_memorySize = value; }
 
     /**
-     * <p>The amount of memory that your function has access to. Increasing the
+     * <p>The amount of memory available to the function at runtime. Increasing the
      * function's memory also increases its CPU allocation. The default value is 128
-     * MB. The value must be a multiple of 64 MB.</p>
+     * MB. The value can be any multiple of 1 MB.</p>
      */
     inline UpdateFunctionConfigurationRequest& WithMemorySize(int value) { SetMemorySize(value); return *this;}
 
@@ -767,6 +759,96 @@ namespace Model
      */
     inline UpdateFunctionConfigurationRequest& AddLayers(const char* value) { m_layersHasBeenSet = true; m_layers.push_back(value); return *this; }
 
+
+    /**
+     * <p>Connection settings for an Amazon EFS file system.</p>
+     */
+    inline const Aws::Vector<FileSystemConfig>& GetFileSystemConfigs() const{ return m_fileSystemConfigs; }
+
+    /**
+     * <p>Connection settings for an Amazon EFS file system.</p>
+     */
+    inline bool FileSystemConfigsHasBeenSet() const { return m_fileSystemConfigsHasBeenSet; }
+
+    /**
+     * <p>Connection settings for an Amazon EFS file system.</p>
+     */
+    inline void SetFileSystemConfigs(const Aws::Vector<FileSystemConfig>& value) { m_fileSystemConfigsHasBeenSet = true; m_fileSystemConfigs = value; }
+
+    /**
+     * <p>Connection settings for an Amazon EFS file system.</p>
+     */
+    inline void SetFileSystemConfigs(Aws::Vector<FileSystemConfig>&& value) { m_fileSystemConfigsHasBeenSet = true; m_fileSystemConfigs = std::move(value); }
+
+    /**
+     * <p>Connection settings for an Amazon EFS file system.</p>
+     */
+    inline UpdateFunctionConfigurationRequest& WithFileSystemConfigs(const Aws::Vector<FileSystemConfig>& value) { SetFileSystemConfigs(value); return *this;}
+
+    /**
+     * <p>Connection settings for an Amazon EFS file system.</p>
+     */
+    inline UpdateFunctionConfigurationRequest& WithFileSystemConfigs(Aws::Vector<FileSystemConfig>&& value) { SetFileSystemConfigs(std::move(value)); return *this;}
+
+    /**
+     * <p>Connection settings for an Amazon EFS file system.</p>
+     */
+    inline UpdateFunctionConfigurationRequest& AddFileSystemConfigs(const FileSystemConfig& value) { m_fileSystemConfigsHasBeenSet = true; m_fileSystemConfigs.push_back(value); return *this; }
+
+    /**
+     * <p>Connection settings for an Amazon EFS file system.</p>
+     */
+    inline UpdateFunctionConfigurationRequest& AddFileSystemConfigs(FileSystemConfig&& value) { m_fileSystemConfigsHasBeenSet = true; m_fileSystemConfigs.push_back(std::move(value)); return *this; }
+
+
+    /**
+     * <p> <a
+     * href="https://docs.aws.amazon.com/lambda/latest/dg/images-parms.html">Container
+     * image configuration values</a> that override the values in the container image
+     * Dockerfile.</p>
+     */
+    inline const ImageConfig& GetImageConfig() const{ return m_imageConfig; }
+
+    /**
+     * <p> <a
+     * href="https://docs.aws.amazon.com/lambda/latest/dg/images-parms.html">Container
+     * image configuration values</a> that override the values in the container image
+     * Dockerfile.</p>
+     */
+    inline bool ImageConfigHasBeenSet() const { return m_imageConfigHasBeenSet; }
+
+    /**
+     * <p> <a
+     * href="https://docs.aws.amazon.com/lambda/latest/dg/images-parms.html">Container
+     * image configuration values</a> that override the values in the container image
+     * Dockerfile.</p>
+     */
+    inline void SetImageConfig(const ImageConfig& value) { m_imageConfigHasBeenSet = true; m_imageConfig = value; }
+
+    /**
+     * <p> <a
+     * href="https://docs.aws.amazon.com/lambda/latest/dg/images-parms.html">Container
+     * image configuration values</a> that override the values in the container image
+     * Dockerfile.</p>
+     */
+    inline void SetImageConfig(ImageConfig&& value) { m_imageConfigHasBeenSet = true; m_imageConfig = std::move(value); }
+
+    /**
+     * <p> <a
+     * href="https://docs.aws.amazon.com/lambda/latest/dg/images-parms.html">Container
+     * image configuration values</a> that override the values in the container image
+     * Dockerfile.</p>
+     */
+    inline UpdateFunctionConfigurationRequest& WithImageConfig(const ImageConfig& value) { SetImageConfig(value); return *this;}
+
+    /**
+     * <p> <a
+     * href="https://docs.aws.amazon.com/lambda/latest/dg/images-parms.html">Container
+     * image configuration values</a> that override the values in the container image
+     * Dockerfile.</p>
+     */
+    inline UpdateFunctionConfigurationRequest& WithImageConfig(ImageConfig&& value) { SetImageConfig(std::move(value)); return *this;}
+
   private:
 
     Aws::String m_functionName;
@@ -810,6 +892,12 @@ namespace Model
 
     Aws::Vector<Aws::String> m_layers;
     bool m_layersHasBeenSet;
+
+    Aws::Vector<FileSystemConfig> m_fileSystemConfigs;
+    bool m_fileSystemConfigsHasBeenSet;
+
+    ImageConfig m_imageConfig;
+    bool m_imageConfigHasBeenSet;
   };
 
 } // namespace Model
