@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/mediaconnect/MediaConnect_EXPORTS.h>
@@ -382,6 +372,47 @@ namespace Model
     inline Source& WithTransport(Transport&& value) { SetTransport(std::move(value)); return *this;}
 
 
+    /**
+     * The name of the VPC Interface this Source is configured with.
+     */
+    inline const Aws::String& GetVpcInterfaceName() const{ return m_vpcInterfaceName; }
+
+    /**
+     * The name of the VPC Interface this Source is configured with.
+     */
+    inline bool VpcInterfaceNameHasBeenSet() const { return m_vpcInterfaceNameHasBeenSet; }
+
+    /**
+     * The name of the VPC Interface this Source is configured with.
+     */
+    inline void SetVpcInterfaceName(const Aws::String& value) { m_vpcInterfaceNameHasBeenSet = true; m_vpcInterfaceName = value; }
+
+    /**
+     * The name of the VPC Interface this Source is configured with.
+     */
+    inline void SetVpcInterfaceName(Aws::String&& value) { m_vpcInterfaceNameHasBeenSet = true; m_vpcInterfaceName = std::move(value); }
+
+    /**
+     * The name of the VPC Interface this Source is configured with.
+     */
+    inline void SetVpcInterfaceName(const char* value) { m_vpcInterfaceNameHasBeenSet = true; m_vpcInterfaceName.assign(value); }
+
+    /**
+     * The name of the VPC Interface this Source is configured with.
+     */
+    inline Source& WithVpcInterfaceName(const Aws::String& value) { SetVpcInterfaceName(value); return *this;}
+
+    /**
+     * The name of the VPC Interface this Source is configured with.
+     */
+    inline Source& WithVpcInterfaceName(Aws::String&& value) { SetVpcInterfaceName(std::move(value)); return *this;}
+
+    /**
+     * The name of the VPC Interface this Source is configured with.
+     */
+    inline Source& WithVpcInterfaceName(const char* value) { SetVpcInterfaceName(value); return *this;}
+
+
     /**
      * The range of IP addresses that should be allowed to contribute content to your
      * source. These IP addresses should be in the form of a Classless Inter-Domain
@@ -467,6 +498,9 @@ namespace Model
     Transport m_transport;
     bool m_transportHasBeenSet;
 
+    Aws::String m_vpcInterfaceName;
+    bool m_vpcInterfaceNameHasBeenSet;
+
     Aws::String m_whitelistCidr;
     bool m_whitelistCidrHasBeenSet;
   };
