@@ -1,26 +1,19 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/mediatailor/MediaTailor_EXPORTS.h>
 #include <aws/mediatailor/MediaTailorRequest.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/mediatailor/model/AvailSuppression.h>
+#include <aws/mediatailor/model/Bumper.h>
 #include <aws/mediatailor/model/CdnConfiguration.h>
+#include <aws/core/utils/memory/stl/AWSMap.h>
 #include <aws/mediatailor/model/DashConfigurationForPut.h>
 #include <aws/mediatailor/model/LivePreRollConfiguration.h>
-#include <aws/core/utils/memory/stl/AWSMap.h>
+#include <aws/mediatailor/model/ManifestProcessingRules.h>
 #include <utility>
 
 namespace Aws
@@ -119,70 +112,265 @@ namespace Model
     inline PutPlaybackConfigurationRequest& WithAdDecisionServerUrl(const char* value) { SetAdDecisionServerUrl(value); return *this;}
 
 
+    /**
+     * <p>The configuration for avail suppression, also known as ad suppression. For
+     * more information about ad suppression, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/ad-behavior.html">Ad
+     * Suppression</a>.</p>
+     */
+    inline const AvailSuppression& GetAvailSuppression() const{ return m_availSuppression; }
+
+    /**
+     * <p>The configuration for avail suppression, also known as ad suppression. For
+     * more information about ad suppression, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/ad-behavior.html">Ad
+     * Suppression</a>.</p>
+     */
+    inline bool AvailSuppressionHasBeenSet() const { return m_availSuppressionHasBeenSet; }
+
+    /**
+     * <p>The configuration for avail suppression, also known as ad suppression. For
+     * more information about ad suppression, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/ad-behavior.html">Ad
+     * Suppression</a>.</p>
+     */
+    inline void SetAvailSuppression(const AvailSuppression& value) { m_availSuppressionHasBeenSet = true; m_availSuppression = value; }
+
+    /**
+     * <p>The configuration for avail suppression, also known as ad suppression. For
+     * more information about ad suppression, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/ad-behavior.html">Ad
+     * Suppression</a>.</p>
+     */
+    inline void SetAvailSuppression(AvailSuppression&& value) { m_availSuppressionHasBeenSet = true; m_availSuppression = std::move(value); }
+
+    /**
+     * <p>The configuration for avail suppression, also known as ad suppression. For
+     * more information about ad suppression, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/ad-behavior.html">Ad
+     * Suppression</a>.</p>
+     */
+    inline PutPlaybackConfigurationRequest& WithAvailSuppression(const AvailSuppression& value) { SetAvailSuppression(value); return *this;}
+
+    /**
+     * <p>The configuration for avail suppression, also known as ad suppression. For
+     * more information about ad suppression, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/ad-behavior.html">Ad
+     * Suppression</a>.</p>
+     */
+    inline PutPlaybackConfigurationRequest& WithAvailSuppression(AvailSuppression&& value) { SetAvailSuppression(std::move(value)); return *this;}
+
+
+    /**
+     * <p>The configuration for bumpers. Bumpers are short audio or video clips that
+     * play at the start or before the end of an ad break. To learn more about bumpers,
+     * see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/bumpers.html">Bumpers</a>.</p>
+     */
+    inline const Bumper& GetBumper() const{ return m_bumper; }
+
+    /**
+     * <p>The configuration for bumpers. Bumpers are short audio or video clips that
+     * play at the start or before the end of an ad break. To learn more about bumpers,
+     * see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/bumpers.html">Bumpers</a>.</p>
+     */
+    inline bool BumperHasBeenSet() const { return m_bumperHasBeenSet; }
+
+    /**
+     * <p>The configuration for bumpers. Bumpers are short audio or video clips that
+     * play at the start or before the end of an ad break. To learn more about bumpers,
+     * see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/bumpers.html">Bumpers</a>.</p>
+     */
+    inline void SetBumper(const Bumper& value) { m_bumperHasBeenSet = true; m_bumper = value; }
+
+    /**
+     * <p>The configuration for bumpers. Bumpers are short audio or video clips that
+     * play at the start or before the end of an ad break. To learn more about bumpers,
+     * see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/bumpers.html">Bumpers</a>.</p>
+     */
+    inline void SetBumper(Bumper&& value) { m_bumperHasBeenSet = true; m_bumper = std::move(value); }
+
+    /**
+     * <p>The configuration for bumpers. Bumpers are short audio or video clips that
+     * play at the start or before the end of an ad break. To learn more about bumpers,
+     * see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/bumpers.html">Bumpers</a>.</p>
+     */
+    inline PutPlaybackConfigurationRequest& WithBumper(const Bumper& value) { SetBumper(value); return *this;}
+
+    /**
+     * <p>The configuration for bumpers. Bumpers are short audio or video clips that
+     * play at the start or before the end of an ad break. To learn more about bumpers,
+     * see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/bumpers.html">Bumpers</a>.</p>
+     */
+    inline PutPlaybackConfigurationRequest& WithBumper(Bumper&& value) { SetBumper(std::move(value)); return *this;}
+
+
     /**
      * <p>The configuration for using a content delivery network (CDN), like Amazon
-     * CloudFront, for content and ad segment management. </p>
+     * CloudFront, for content and ad segment management.</p>
      */
     inline const CdnConfiguration& GetCdnConfiguration() const{ return m_cdnConfiguration; }
 
     /**
      * <p>The configuration for using a content delivery network (CDN), like Amazon
-     * CloudFront, for content and ad segment management. </p>
+     * CloudFront, for content and ad segment management.</p>
      */
     inline bool CdnConfigurationHasBeenSet() const { return m_cdnConfigurationHasBeenSet; }
 
     /**
      * <p>The configuration for using a content delivery network (CDN), like Amazon
-     * CloudFront, for content and ad segment management. </p>
+     * CloudFront, for content and ad segment management.</p>
      */
     inline void SetCdnConfiguration(const CdnConfiguration& value) { m_cdnConfigurationHasBeenSet = true; m_cdnConfiguration = value; }
 
     /**
      * <p>The configuration for using a content delivery network (CDN), like Amazon
-     * CloudFront, for content and ad segment management. </p>
+     * CloudFront, for content and ad segment management.</p>
      */
     inline void SetCdnConfiguration(CdnConfiguration&& value) { m_cdnConfigurationHasBeenSet = true; m_cdnConfiguration = std::move(value); }
 
     /**
      * <p>The configuration for using a content delivery network (CDN), like Amazon
-     * CloudFront, for content and ad segment management. </p>
+     * CloudFront, for content and ad segment management.</p>
      */
     inline PutPlaybackConfigurationRequest& WithCdnConfiguration(const CdnConfiguration& value) { SetCdnConfiguration(value); return *this;}
 
     /**
      * <p>The configuration for using a content delivery network (CDN), like Amazon
-     * CloudFront, for content and ad segment management. </p>
+     * CloudFront, for content and ad segment management.</p>
      */
     inline PutPlaybackConfigurationRequest& WithCdnConfiguration(CdnConfiguration&& value) { SetCdnConfiguration(std::move(value)); return *this;}
 
 
     /**
-     * <p>The configuration for DASH content. </p>
+     * <p>The player parameters and aliases used as dynamic variables during session
+     * initialization. For more information, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/variables-domain.html">Domain
+     * Variables</a>.</p> 
+     */
+    inline const Aws::Map<Aws::String, Aws::Map<Aws::String, Aws::String>>& GetConfigurationAliases() const{ return m_configurationAliases; }
+
+    /**
+     * <p>The player parameters and aliases used as dynamic variables during session
+     * initialization. For more information, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/variables-domain.html">Domain
+     * Variables</a>.</p> 
+     */
+    inline bool ConfigurationAliasesHasBeenSet() const { return m_configurationAliasesHasBeenSet; }
+
+    /**
+     * <p>The player parameters and aliases used as dynamic variables during session
+     * initialization. For more information, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/variables-domain.html">Domain
+     * Variables</a>.</p> 
+     */
+    inline void SetConfigurationAliases(const Aws::Map<Aws::String, Aws::Map<Aws::String, Aws::String>>& value) { m_configurationAliasesHasBeenSet = true; m_configurationAliases = value; }
+
+    /**
+     * <p>The player parameters and aliases used as dynamic variables during session
+     * initialization. For more information, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/variables-domain.html">Domain
+     * Variables</a>.</p> 
+     */
+    inline void SetConfigurationAliases(Aws::Map<Aws::String, Aws::Map<Aws::String, Aws::String>>&& value) { m_configurationAliasesHasBeenSet = true; m_configurationAliases = std::move(value); }
+
+    /**
+     * <p>The player parameters and aliases used as dynamic variables during session
+     * initialization. For more information, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/variables-domain.html">Domain
+     * Variables</a>.</p> 
+     */
+    inline PutPlaybackConfigurationRequest& WithConfigurationAliases(const Aws::Map<Aws::String, Aws::Map<Aws::String, Aws::String>>& value) { SetConfigurationAliases(value); return *this;}
+
+    /**
+     * <p>The player parameters and aliases used as dynamic variables during session
+     * initialization. For more information, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/variables-domain.html">Domain
+     * Variables</a>.</p> 
+     */
+    inline PutPlaybackConfigurationRequest& WithConfigurationAliases(Aws::Map<Aws::String, Aws::Map<Aws::String, Aws::String>>&& value) { SetConfigurationAliases(std::move(value)); return *this;}
+
+    /**
+     * <p>The player parameters and aliases used as dynamic variables during session
+     * initialization. For more information, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/variables-domain.html">Domain
+     * Variables</a>.</p> 
+     */
+    inline PutPlaybackConfigurationRequest& AddConfigurationAliases(const Aws::String& key, const Aws::Map<Aws::String, Aws::String>& value) { m_configurationAliasesHasBeenSet = true; m_configurationAliases.emplace(key, value); return *this; }
+
+    /**
+     * <p>The player parameters and aliases used as dynamic variables during session
+     * initialization. For more information, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/variables-domain.html">Domain
+     * Variables</a>.</p> 
+     */
+    inline PutPlaybackConfigurationRequest& AddConfigurationAliases(Aws::String&& key, const Aws::Map<Aws::String, Aws::String>& value) { m_configurationAliasesHasBeenSet = true; m_configurationAliases.emplace(std::move(key), value); return *this; }
+
+    /**
+     * <p>The player parameters and aliases used as dynamic variables during session
+     * initialization. For more information, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/variables-domain.html">Domain
+     * Variables</a>.</p> 
+     */
+    inline PutPlaybackConfigurationRequest& AddConfigurationAliases(const Aws::String& key, Aws::Map<Aws::String, Aws::String>&& value) { m_configurationAliasesHasBeenSet = true; m_configurationAliases.emplace(key, std::move(value)); return *this; }
+
+    /**
+     * <p>The player parameters and aliases used as dynamic variables during session
+     * initialization. For more information, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/variables-domain.html">Domain
+     * Variables</a>.</p> 
+     */
+    inline PutPlaybackConfigurationRequest& AddConfigurationAliases(Aws::String&& key, Aws::Map<Aws::String, Aws::String>&& value) { m_configurationAliasesHasBeenSet = true; m_configurationAliases.emplace(std::move(key), std::move(value)); return *this; }
+
+    /**
+     * <p>The player parameters and aliases used as dynamic variables during session
+     * initialization. For more information, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/variables-domain.html">Domain
+     * Variables</a>.</p> 
+     */
+    inline PutPlaybackConfigurationRequest& AddConfigurationAliases(const char* key, Aws::Map<Aws::String, Aws::String>&& value) { m_configurationAliasesHasBeenSet = true; m_configurationAliases.emplace(key, std::move(value)); return *this; }
+
+    /**
+     * <p>The player parameters and aliases used as dynamic variables during session
+     * initialization. For more information, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/variables-domain.html">Domain
+     * Variables</a>.</p> 
+     */
+    inline PutPlaybackConfigurationRequest& AddConfigurationAliases(const char* key, const Aws::Map<Aws::String, Aws::String>& value) { m_configurationAliasesHasBeenSet = true; m_configurationAliases.emplace(key, value); return *this; }
+
+
+    /**
+     * <p>The configuration for DASH content.</p>
      */
     inline const DashConfigurationForPut& GetDashConfiguration() const{ return m_dashConfiguration; }
 
     /**
-     * <p>The configuration for DASH content. </p>
+     * <p>The configuration for DASH content.</p>
      */
     inline bool DashConfigurationHasBeenSet() const { return m_dashConfigurationHasBeenSet; }
 
     /**
-     * <p>The configuration for DASH content. </p>
+     * <p>The configuration for DASH content.</p>
      */
     inline void SetDashConfiguration(const DashConfigurationForPut& value) { m_dashConfigurationHasBeenSet = true; m_dashConfiguration = value; }
 
     /**
-     * <p>The configuration for DASH content. </p>
+     * <p>The configuration for DASH content.</p>
      */
     inline void SetDashConfiguration(DashConfigurationForPut&& value) { m_dashConfigurationHasBeenSet = true; m_dashConfiguration = std::move(value); }
 
     /**
-     * <p>The configuration for DASH content. </p>
+     * <p>The configuration for DASH content.</p>
      */
     inline PutPlaybackConfigurationRequest& WithDashConfiguration(const DashConfigurationForPut& value) { SetDashConfiguration(value); return *this;}
 
     /**
-     * <p>The configuration for DASH content. </p>
+     * <p>The configuration for DASH content.</p>
      */
     inline PutPlaybackConfigurationRequest& WithDashConfiguration(DashConfigurationForPut&& value) { SetDashConfiguration(std::move(value)); return *this;}
 
@@ -218,6 +406,43 @@ namespace Model
     inline PutPlaybackConfigurationRequest& WithLivePreRollConfiguration(LivePreRollConfiguration&& value) { SetLivePreRollConfiguration(std::move(value)); return *this;}
 
 
+    /**
+     * <p>The configuration for manifest processing rules. Manifest processing rules
+     * enable customization of the personalized manifests created by MediaTailor.</p>
+     */
+    inline const ManifestProcessingRules& GetManifestProcessingRules() const{ return m_manifestProcessingRules; }
+
+    /**
+     * <p>The configuration for manifest processing rules. Manifest processing rules
+     * enable customization of the personalized manifests created by MediaTailor.</p>
+     */
+    inline bool ManifestProcessingRulesHasBeenSet() const { return m_manifestProcessingRulesHasBeenSet; }
+
+    /**
+     * <p>The configuration for manifest processing rules. Manifest processing rules
+     * enable customization of the personalized manifests created by MediaTailor.</p>
+     */
+    inline void SetManifestProcessingRules(const ManifestProcessingRules& value) { m_manifestProcessingRulesHasBeenSet = true; m_manifestProcessingRules = value; }
+
+    /**
+     * <p>The configuration for manifest processing rules. Manifest processing rules
+     * enable customization of the personalized manifests created by MediaTailor.</p>
+     */
+    inline void SetManifestProcessingRules(ManifestProcessingRules&& value) { m_manifestProcessingRulesHasBeenSet = true; m_manifestProcessingRules = std::move(value); }
+
+    /**
+     * <p>The configuration for manifest processing rules. Manifest processing rules
+     * enable customization of the personalized manifests created by MediaTailor.</p>
+     */
+    inline PutPlaybackConfigurationRequest& WithManifestProcessingRules(const ManifestProcessingRules& value) { SetManifestProcessingRules(value); return *this;}
+
+    /**
+     * <p>The configuration for manifest processing rules. Manifest processing rules
+     * enable customization of the personalized manifests created by MediaTailor.</p>
+     */
+    inline PutPlaybackConfigurationRequest& WithManifestProcessingRules(ManifestProcessingRules&& value) { SetManifestProcessingRules(std::move(value)); return *this;}
+
+
     /**
      * <p>The identifier for the playback configuration.</p>
      */
@@ -260,26 +485,54 @@ namespace Model
 
 
     /**
-     * <p>The maximum duration of underfilled ad time (in seconds) allowed in an ad
-     * break.</p>
+     * <p>Defines the maximum duration of underfilled ad time (in seconds) allowed in
+     * an ad break. If the duration of underfilled ad time exceeds the personalization
+     * threshold, then the personalization of the ad break is abandoned and the
+     * underlying content is shown. This feature applies to <i>ad replacement</i> in
+     * live and VOD streams, rather than ad insertion, because it relies on an
+     * underlying content stream. For more information about ad break behavior,
+     * including ad replacement and insertion, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/ad-behavior.html">Ad
+     * Behavior in AWS Elemental MediaTailor</a>.</p>
      */
     inline int GetPersonalizationThresholdSeconds() const{ return m_personalizationThresholdSeconds; }
 
     /**
-     * <p>The maximum duration of underfilled ad time (in seconds) allowed in an ad
-     * break.</p>
+     * <p>Defines the maximum duration of underfilled ad time (in seconds) allowed in
+     * an ad break. If the duration of underfilled ad time exceeds the personalization
+     * threshold, then the personalization of the ad break is abandoned and the
+     * underlying content is shown. This feature applies to <i>ad replacement</i> in
+     * live and VOD streams, rather than ad insertion, because it relies on an
+     * underlying content stream. For more information about ad break behavior,
+     * including ad replacement and insertion, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/ad-behavior.html">Ad
+     * Behavior in AWS Elemental MediaTailor</a>.</p>
      */
     inline bool PersonalizationThresholdSecondsHasBeenSet() const { return m_personalizationThresholdSecondsHasBeenSet; }
 
     /**
-     * <p>The maximum duration of underfilled ad time (in seconds) allowed in an ad
-     * break.</p>
+     * <p>Defines the maximum duration of underfilled ad time (in seconds) allowed in
+     * an ad break. If the duration of underfilled ad time exceeds the personalization
+     * threshold, then the personalization of the ad break is abandoned and the
+     * underlying content is shown. This feature applies to <i>ad replacement</i> in
+     * live and VOD streams, rather than ad insertion, because it relies on an
+     * underlying content stream. For more information about ad break behavior,
+     * including ad replacement and insertion, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/ad-behavior.html">Ad
+     * Behavior in AWS Elemental MediaTailor</a>.</p>
      */
     inline void SetPersonalizationThresholdSeconds(int value) { m_personalizationThresholdSecondsHasBeenSet = true; m_personalizationThresholdSeconds = value; }
 
     /**
-     * <p>The maximum duration of underfilled ad time (in seconds) allowed in an ad
-     * break.</p>
+     * <p>Defines the maximum duration of underfilled ad time (in seconds) allowed in
+     * an ad break. If the duration of underfilled ad time exceeds the personalization
+     * threshold, then the personalization of the ad break is abandoned and the
+     * underlying content is shown. This feature applies to <i>ad replacement</i> in
+     * live and VOD streams, rather than ad insertion, because it relies on an
+     * underlying content stream. For more information about ad break behavior,
+     * including ad replacement and insertion, see <a
+     * href="https://docs.aws.amazon.com/mediatailor/latest/ug/ad-behavior.html">Ad
+     * Behavior in AWS Elemental MediaTailor</a>.</p>
      */
     inline PutPlaybackConfigurationRequest& WithPersonalizationThresholdSeconds(int value) { SetPersonalizationThresholdSeconds(value); return *this;}
 
@@ -290,7 +543,7 @@ namespace Model
      * gaps in media content. Configuring the slate is optional for non-VPAID
      * configurations. For VPAID, the slate is required because MediaTailor provides it
      * in the slots that are designated for dynamic ad content. The slate must be a
-     * high-quality asset that contains both audio and video. </p>
+     * high-quality asset that contains both audio and video.</p>
      */
     inline const Aws::String& GetSlateAdUrl() const{ return m_slateAdUrl; }
 
@@ -300,7 +553,7 @@ namespace Model
      * gaps in media content. Configuring the slate is optional for non-VPAID
      * configurations. For VPAID, the slate is required because MediaTailor provides it
      * in the slots that are designated for dynamic ad content. The slate must be a
-     * high-quality asset that contains both audio and video. </p>
+     * high-quality asset that contains both audio and video.</p>
      */
     inline bool SlateAdUrlHasBeenSet() const { return m_slateAdUrlHasBeenSet; }
 
@@ -310,7 +563,7 @@ namespace Model
      * gaps in media content. Configuring the slate is optional for non-VPAID
      * configurations. For VPAID, the slate is required because MediaTailor provides it
      * in the slots that are designated for dynamic ad content. The slate must be a
-     * high-quality asset that contains both audio and video. </p>
+     * high-quality asset that contains both audio and video.</p>
      */
     inline void SetSlateAdUrl(const Aws::String& value) { m_slateAdUrlHasBeenSet = true; m_slateAdUrl = value; }
 
@@ -320,7 +573,7 @@ namespace Model
      * gaps in media content. Configuring the slate is optional for non-VPAID
      * configurations. For VPAID, the slate is required because MediaTailor provides it
      * in the slots that are designated for dynamic ad content. The slate must be a
-     * high-quality asset that contains both audio and video. </p>
+     * high-quality asset that contains both audio and video.</p>
      */
     inline void SetSlateAdUrl(Aws::String&& value) { m_slateAdUrlHasBeenSet = true; m_slateAdUrl = std::move(value); }
 
@@ -330,7 +583,7 @@ namespace Model
      * gaps in media content. Configuring the slate is optional for non-VPAID
      * configurations. For VPAID, the slate is required because MediaTailor provides it
      * in the slots that are designated for dynamic ad content. The slate must be a
-     * high-quality asset that contains both audio and video. </p>
+     * high-quality asset that contains both audio and video.</p>
      */
     inline void SetSlateAdUrl(const char* value) { m_slateAdUrlHasBeenSet = true; m_slateAdUrl.assign(value); }
 
@@ -340,7 +593,7 @@ namespace Model
      * gaps in media content. Configuring the slate is optional for non-VPAID
      * configurations. For VPAID, the slate is required because MediaTailor provides it
      * in the slots that are designated for dynamic ad content. The slate must be a
-     * high-quality asset that contains both audio and video. </p>
+     * high-quality asset that contains both audio and video.</p>
      */
     inline PutPlaybackConfigurationRequest& WithSlateAdUrl(const Aws::String& value) { SetSlateAdUrl(value); return *this;}
 
@@ -350,7 +603,7 @@ namespace Model
      * gaps in media content. Configuring the slate is optional for non-VPAID
      * configurations. For VPAID, the slate is required because MediaTailor provides it
      * in the slots that are designated for dynamic ad content. The slate must be a
-     * high-quality asset that contains both audio and video. </p>
+     * high-quality asset that contains both audio and video.</p>
      */
     inline PutPlaybackConfigurationRequest& WithSlateAdUrl(Aws::String&& value) { SetSlateAdUrl(std::move(value)); return *this;}
 
@@ -360,73 +613,73 @@ namespace Model
      * gaps in media content. Configuring the slate is optional for non-VPAID
      * configurations. For VPAID, the slate is required because MediaTailor provides it
      * in the slots that are designated for dynamic ad content. The slate must be a
-     * high-quality asset that contains both audio and video. </p>
+     * high-quality asset that contains both audio and video.</p>
      */
     inline PutPlaybackConfigurationRequest& WithSlateAdUrl(const char* value) { SetSlateAdUrl(value); return *this;}
 
 
     /**
-     * <p>The tags to assign to the playback configuration. </p>
+     * <p>The tags to assign to the playback configuration.</p>
      */
     inline const Aws::Map<Aws::String, Aws::String>& GetTags() const{ return m_tags; }
 
     /**
-     * <p>The tags to assign to the playback configuration. </p>
+     * <p>The tags to assign to the playback configuration.</p>
      */
     inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
 
     /**
-     * <p>The tags to assign to the playback configuration. </p>
+     * <p>The tags to assign to the playback configuration.</p>
      */
     inline void SetTags(const Aws::Map<Aws::String, Aws::String>& value) { m_tagsHasBeenSet = true; m_tags = value; }
 
     /**
-     * <p>The tags to assign to the playback configuration. </p>
+     * <p>The tags to assign to the playback configuration.</p>
      */
     inline void SetTags(Aws::Map<Aws::String, Aws::String>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
 
     /**
-     * <p>The tags to assign to the playback configuration. </p>
+     * <p>The tags to assign to the playback configuration.</p>
      */
     inline PutPlaybackConfigurationRequest& WithTags(const Aws::Map<Aws::String, Aws::String>& value) { SetTags(value); return *this;}
 
     /**
-     * <p>The tags to assign to the playback configuration. </p>
+     * <p>The tags to assign to the playback configuration.</p>
      */
     inline PutPlaybackConfigurationRequest& WithTags(Aws::Map<Aws::String, Aws::String>&& value) { SetTags(std::move(value)); return *this;}
 
     /**
-     * <p>The tags to assign to the playback configuration. </p>
+     * <p>The tags to assign to the playback configuration.</p>
      */
     inline PutPlaybackConfigurationRequest& AddTags(const Aws::String& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
 
     /**
-     * <p>The tags to assign to the playback configuration. </p>
+     * <p>The tags to assign to the playback configuration.</p>
      */
     inline PutPlaybackConfigurationRequest& AddTags(Aws::String&& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
 
     /**
-     * <p>The tags to assign to the playback configuration. </p>
+     * <p>The tags to assign to the playback configuration.</p>
      */
     inline PutPlaybackConfigurationRequest& AddTags(const Aws::String& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
 
     /**
-     * <p>The tags to assign to the playback configuration. </p>
+     * <p>The tags to assign to the playback configuration.</p>
      */
     inline PutPlaybackConfigurationRequest& AddTags(Aws::String&& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), std::move(value)); return *this; }
 
     /**
-     * <p>The tags to assign to the playback configuration. </p>
+     * <p>The tags to assign to the playback configuration.</p>
      */
     inline PutPlaybackConfigurationRequest& AddTags(const char* key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
 
     /**
-     * <p>The tags to assign to the playback configuration. </p>
+     * <p>The tags to assign to the playback configuration.</p>
      */
     inline PutPlaybackConfigurationRequest& AddTags(Aws::String&& key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
 
     /**
-     * <p>The tags to assign to the playback configuration. </p>
+     * <p>The tags to assign to the playback configuration.</p>
      */
     inline PutPlaybackConfigurationRequest& AddTags(const char* key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
 
@@ -497,49 +750,49 @@ namespace Model
 
 
     /**
-     * <p>The URL prefix for the master playlist for the stream, minus the asset ID.
+     * <p>The URL prefix for the parent manifest for the stream, minus the asset ID.
      * The maximum length is 512 characters.</p>
      */
     inline const Aws::String& GetVideoContentSourceUrl() const{ return m_videoContentSourceUrl; }
 
     /**
-     * <p>The URL prefix for the master playlist for the stream, minus the asset ID.
+     * <p>The URL prefix for the parent manifest for the stream, minus the asset ID.
      * The maximum length is 512 characters.</p>
      */
     inline bool VideoContentSourceUrlHasBeenSet() const { return m_videoContentSourceUrlHasBeenSet; }
 
     /**
-     * <p>The URL prefix for the master playlist for the stream, minus the asset ID.
+     * <p>The URL prefix for the parent manifest for the stream, minus the asset ID.
      * The maximum length is 512 characters.</p>
      */
     inline void SetVideoContentSourceUrl(const Aws::String& value) { m_videoContentSourceUrlHasBeenSet = true; m_videoContentSourceUrl = value; }
 
     /**
-     * <p>The URL prefix for the master playlist for the stream, minus the asset ID.
+     * <p>The URL prefix for the parent manifest for the stream, minus the asset ID.
      * The maximum length is 512 characters.</p>
      */
     inline void SetVideoContentSourceUrl(Aws::String&& value) { m_videoContentSourceUrlHasBeenSet = true; m_videoContentSourceUrl = std::move(value); }
 
     /**
-     * <p>The URL prefix for the master playlist for the stream, minus the asset ID.
+     * <p>The URL prefix for the parent manifest for the stream, minus the asset ID.
      * The maximum length is 512 characters.</p>
      */
     inline void SetVideoContentSourceUrl(const char* value) { m_videoContentSourceUrlHasBeenSet = true; m_videoContentSourceUrl.assign(value); }
 
     /**
-     * <p>The URL prefix for the master playlist for the stream, minus the asset ID.
+     * <p>The URL prefix for the parent manifest for the stream, minus the asset ID.
      * The maximum length is 512 characters.</p>
      */
     inline PutPlaybackConfigurationRequest& WithVideoContentSourceUrl(const Aws::String& value) { SetVideoContentSourceUrl(value); return *this;}
 
     /**
-     * <p>The URL prefix for the master playlist for the stream, minus the asset ID.
+     * <p>The URL prefix for the parent manifest for the stream, minus the asset ID.
      * The maximum length is 512 characters.</p>
      */
     inline PutPlaybackConfigurationRequest& WithVideoContentSourceUrl(Aws::String&& value) { SetVideoContentSourceUrl(std::move(value)); return *this;}
 
     /**
-     * <p>The URL prefix for the master playlist for the stream, minus the asset ID.
+     * <p>The URL prefix for the parent manifest for the stream, minus the asset ID.
      * The maximum length is 512 characters.</p>
      */
     inline PutPlaybackConfigurationRequest& WithVideoContentSourceUrl(const char* value) { SetVideoContentSourceUrl(value); return *this;}
@@ -549,15 +802,27 @@ namespace Model
     Aws::String m_adDecisionServerUrl;
     bool m_adDecisionServerUrlHasBeenSet;
 
+    AvailSuppression m_availSuppression;
+    bool m_availSuppressionHasBeenSet;
+
+    Bumper m_bumper;
+    bool m_bumperHasBeenSet;
+
     CdnConfiguration m_cdnConfiguration;
     bool m_cdnConfigurationHasBeenSet;
 
+    Aws::Map<Aws::String, Aws::Map<Aws::String, Aws::String>> m_configurationAliases;
+    bool m_configurationAliasesHasBeenSet;
+
     DashConfigurationForPut m_dashConfiguration;
     bool m_dashConfigurationHasBeenSet;
 
     LivePreRollConfiguration m_livePreRollConfiguration;
     bool m_livePreRollConfigurationHasBeenSet;
 
+    ManifestProcessingRules m_manifestProcessingRules;
+    bool m_manifestProcessingRulesHasBeenSet;
+
     Aws::String m_name;
     bool m_nameHasBeenSet;
 
