@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/secretsmanager/SecretsManager_EXPORTS.h>
@@ -227,156 +217,156 @@ namespace Model
 
 
     /**
-     * <p>The ARN or alias of the AWS KMS customer master key (CMK) that's used to
-     * encrypt the <code>SecretString</code> and <code>SecretBinary</code> fields in
-     * each version of the secret. If you don't provide a key, then Secrets Manager
-     * defaults to encrypting the secret fields with the default KMS CMK (the one named
-     * <code>awssecretsmanager</code>) for this account.</p>
+     * <p>The ARN or alias of the AWS KMS customer master key (CMK) used to encrypt the
+     * <code>SecretString</code> and <code>SecretBinary</code> fields in each version
+     * of the secret. If you don't provide a key, then Secrets Manager defaults to
+     * encrypting the secret fields with the default KMS CMK, the key named
+     * <code>awssecretsmanager</code>, for this account.</p>
      */
     inline const Aws::String& GetKmsKeyId() const{ return m_kmsKeyId; }
 
     /**
-     * <p>The ARN or alias of the AWS KMS customer master key (CMK) that's used to
-     * encrypt the <code>SecretString</code> and <code>SecretBinary</code> fields in
-     * each version of the secret. If you don't provide a key, then Secrets Manager
-     * defaults to encrypting the secret fields with the default KMS CMK (the one named
-     * <code>awssecretsmanager</code>) for this account.</p>
+     * <p>The ARN or alias of the AWS KMS customer master key (CMK) used to encrypt the
+     * <code>SecretString</code> and <code>SecretBinary</code> fields in each version
+     * of the secret. If you don't provide a key, then Secrets Manager defaults to
+     * encrypting the secret fields with the default KMS CMK, the key named
+     * <code>awssecretsmanager</code>, for this account.</p>
      */
     inline bool KmsKeyIdHasBeenSet() const { return m_kmsKeyIdHasBeenSet; }
 
     /**
-     * <p>The ARN or alias of the AWS KMS customer master key (CMK) that's used to
-     * encrypt the <code>SecretString</code> and <code>SecretBinary</code> fields in
-     * each version of the secret. If you don't provide a key, then Secrets Manager
-     * defaults to encrypting the secret fields with the default KMS CMK (the one named
-     * <code>awssecretsmanager</code>) for this account.</p>
+     * <p>The ARN or alias of the AWS KMS customer master key (CMK) used to encrypt the
+     * <code>SecretString</code> and <code>SecretBinary</code> fields in each version
+     * of the secret. If you don't provide a key, then Secrets Manager defaults to
+     * encrypting the secret fields with the default KMS CMK, the key named
+     * <code>awssecretsmanager</code>, for this account.</p>
      */
     inline void SetKmsKeyId(const Aws::String& value) { m_kmsKeyIdHasBeenSet = true; m_kmsKeyId = value; }
 
     /**
-     * <p>The ARN or alias of the AWS KMS customer master key (CMK) that's used to
-     * encrypt the <code>SecretString</code> and <code>SecretBinary</code> fields in
-     * each version of the secret. If you don't provide a key, then Secrets Manager
-     * defaults to encrypting the secret fields with the default KMS CMK (the one named
-     * <code>awssecretsmanager</code>) for this account.</p>
+     * <p>The ARN or alias of the AWS KMS customer master key (CMK) used to encrypt the
+     * <code>SecretString</code> and <code>SecretBinary</code> fields in each version
+     * of the secret. If you don't provide a key, then Secrets Manager defaults to
+     * encrypting the secret fields with the default KMS CMK, the key named
+     * <code>awssecretsmanager</code>, for this account.</p>
      */
     inline void SetKmsKeyId(Aws::String&& value) { m_kmsKeyIdHasBeenSet = true; m_kmsKeyId = std::move(value); }
 
     /**
-     * <p>The ARN or alias of the AWS KMS customer master key (CMK) that's used to
-     * encrypt the <code>SecretString</code> and <code>SecretBinary</code> fields in
-     * each version of the secret. If you don't provide a key, then Secrets Manager
-     * defaults to encrypting the secret fields with the default KMS CMK (the one named
-     * <code>awssecretsmanager</code>) for this account.</p>
+     * <p>The ARN or alias of the AWS KMS customer master key (CMK) used to encrypt the
+     * <code>SecretString</code> and <code>SecretBinary</code> fields in each version
+     * of the secret. If you don't provide a key, then Secrets Manager defaults to
+     * encrypting the secret fields with the default KMS CMK, the key named
+     * <code>awssecretsmanager</code>, for this account.</p>
      */
     inline void SetKmsKeyId(const char* value) { m_kmsKeyIdHasBeenSet = true; m_kmsKeyId.assign(value); }
 
     /**
-     * <p>The ARN or alias of the AWS KMS customer master key (CMK) that's used to
-     * encrypt the <code>SecretString</code> and <code>SecretBinary</code> fields in
-     * each version of the secret. If you don't provide a key, then Secrets Manager
-     * defaults to encrypting the secret fields with the default KMS CMK (the one named
-     * <code>awssecretsmanager</code>) for this account.</p>
+     * <p>The ARN or alias of the AWS KMS customer master key (CMK) used to encrypt the
+     * <code>SecretString</code> and <code>SecretBinary</code> fields in each version
+     * of the secret. If you don't provide a key, then Secrets Manager defaults to
+     * encrypting the secret fields with the default KMS CMK, the key named
+     * <code>awssecretsmanager</code>, for this account.</p>
      */
     inline SecretListEntry& WithKmsKeyId(const Aws::String& value) { SetKmsKeyId(value); return *this;}
 
     /**
-     * <p>The ARN or alias of the AWS KMS customer master key (CMK) that's used to
-     * encrypt the <code>SecretString</code> and <code>SecretBinary</code> fields in
-     * each version of the secret. If you don't provide a key, then Secrets Manager
-     * defaults to encrypting the secret fields with the default KMS CMK (the one named
-     * <code>awssecretsmanager</code>) for this account.</p>
+     * <p>The ARN or alias of the AWS KMS customer master key (CMK) used to encrypt the
+     * <code>SecretString</code> and <code>SecretBinary</code> fields in each version
+     * of the secret. If you don't provide a key, then Secrets Manager defaults to
+     * encrypting the secret fields with the default KMS CMK, the key named
+     * <code>awssecretsmanager</code>, for this account.</p>
      */
     inline SecretListEntry& WithKmsKeyId(Aws::String&& value) { SetKmsKeyId(std::move(value)); return *this;}
 
     /**
-     * <p>The ARN or alias of the AWS KMS customer master key (CMK) that's used to
-     * encrypt the <code>SecretString</code> and <code>SecretBinary</code> fields in
-     * each version of the secret. If you don't provide a key, then Secrets Manager
-     * defaults to encrypting the secret fields with the default KMS CMK (the one named
-     * <code>awssecretsmanager</code>) for this account.</p>
+     * <p>The ARN or alias of the AWS KMS customer master key (CMK) used to encrypt the
+     * <code>SecretString</code> and <code>SecretBinary</code> fields in each version
+     * of the secret. If you don't provide a key, then Secrets Manager defaults to
+     * encrypting the secret fields with the default KMS CMK, the key named
+     * <code>awssecretsmanager</code>, for this account.</p>
      */
     inline SecretListEntry& WithKmsKeyId(const char* value) { SetKmsKeyId(value); return *this;}
 
 
     /**
-     * <p>Indicated whether automatic, scheduled rotation is enabled for this
+     * <p>Indicates whether automatic, scheduled rotation is enabled for this
      * secret.</p>
      */
     inline bool GetRotationEnabled() const{ return m_rotationEnabled; }
 
     /**
-     * <p>Indicated whether automatic, scheduled rotation is enabled for this
+     * <p>Indicates whether automatic, scheduled rotation is enabled for this
      * secret.</p>
      */
     inline bool RotationEnabledHasBeenSet() const { return m_rotationEnabledHasBeenSet; }
 
     /**
-     * <p>Indicated whether automatic, scheduled rotation is enabled for this
+     * <p>Indicates whether automatic, scheduled rotation is enabled for this
      * secret.</p>
      */
     inline void SetRotationEnabled(bool value) { m_rotationEnabledHasBeenSet = true; m_rotationEnabled = value; }
 
     /**
-     * <p>Indicated whether automatic, scheduled rotation is enabled for this
+     * <p>Indicates whether automatic, scheduled rotation is enabled for this
      * secret.</p>
      */
     inline SecretListEntry& WithRotationEnabled(bool value) { SetRotationEnabled(value); return *this;}
 
 
     /**
-     * <p>The ARN of an AWS Lambda function that's invoked by Secrets Manager to rotate
-     * and expire the secret either automatically per the schedule or manually by a
-     * call to <a>RotateSecret</a>.</p>
+     * <p>The ARN of an AWS Lambda function invoked by Secrets Manager to rotate and
+     * expire the secret either automatically per the schedule or manually by a call to
+     * <a>RotateSecret</a>.</p>
      */
     inline const Aws::String& GetRotationLambdaARN() const{ return m_rotationLambdaARN; }
 
     /**
-     * <p>The ARN of an AWS Lambda function that's invoked by Secrets Manager to rotate
-     * and expire the secret either automatically per the schedule or manually by a
-     * call to <a>RotateSecret</a>.</p>
+     * <p>The ARN of an AWS Lambda function invoked by Secrets Manager to rotate and
+     * expire the secret either automatically per the schedule or manually by a call to
+     * <a>RotateSecret</a>.</p>
      */
     inline bool RotationLambdaARNHasBeenSet() const { return m_rotationLambdaARNHasBeenSet; }
 
     /**
-     * <p>The ARN of an AWS Lambda function that's invoked by Secrets Manager to rotate
-     * and expire the secret either automatically per the schedule or manually by a
-     * call to <a>RotateSecret</a>.</p>
+     * <p>The ARN of an AWS Lambda function invoked by Secrets Manager to rotate and
+     * expire the secret either automatically per the schedule or manually by a call to
+     * <a>RotateSecret</a>.</p>
      */
     inline void SetRotationLambdaARN(const Aws::String& value) { m_rotationLambdaARNHasBeenSet = true; m_rotationLambdaARN = value; }
 
     /**
-     * <p>The ARN of an AWS Lambda function that's invoked by Secrets Manager to rotate
-     * and expire the secret either automatically per the schedule or manually by a
-     * call to <a>RotateSecret</a>.</p>
+     * <p>The ARN of an AWS Lambda function invoked by Secrets Manager to rotate and
+     * expire the secret either automatically per the schedule or manually by a call to
+     * <a>RotateSecret</a>.</p>
      */
     inline void SetRotationLambdaARN(Aws::String&& value) { m_rotationLambdaARNHasBeenSet = true; m_rotationLambdaARN = std::move(value); }
 
     /**
-     * <p>The ARN of an AWS Lambda function that's invoked by Secrets Manager to rotate
-     * and expire the secret either automatically per the schedule or manually by a
-     * call to <a>RotateSecret</a>.</p>
+     * <p>The ARN of an AWS Lambda function invoked by Secrets Manager to rotate and
+     * expire the secret either automatically per the schedule or manually by a call to
+     * <a>RotateSecret</a>.</p>
      */
     inline void SetRotationLambdaARN(const char* value) { m_rotationLambdaARNHasBeenSet = true; m_rotationLambdaARN.assign(value); }
 
     /**
-     * <p>The ARN of an AWS Lambda function that's invoked by Secrets Manager to rotate
-     * and expire the secret either automatically per the schedule or manually by a
-     * call to <a>RotateSecret</a>.</p>
+     * <p>The ARN of an AWS Lambda function invoked by Secrets Manager to rotate and
+     * expire the secret either automatically per the schedule or manually by a call to
+     * <a>RotateSecret</a>.</p>
      */
     inline SecretListEntry& WithRotationLambdaARN(const Aws::String& value) { SetRotationLambdaARN(value); return *this;}
 
     /**
-     * <p>The ARN of an AWS Lambda function that's invoked by Secrets Manager to rotate
-     * and expire the secret either automatically per the schedule or manually by a
-     * call to <a>RotateSecret</a>.</p>
+     * <p>The ARN of an AWS Lambda function invoked by Secrets Manager to rotate and
+     * expire the secret either automatically per the schedule or manually by a call to
+     * <a>RotateSecret</a>.</p>
      */
     inline SecretListEntry& WithRotationLambdaARN(Aws::String&& value) { SetRotationLambdaARN(std::move(value)); return *this;}
 
     /**
-     * <p>The ARN of an AWS Lambda function that's invoked by Secrets Manager to rotate
-     * and expire the secret either automatically per the schedule or manually by a
-     * call to <a>RotateSecret</a>.</p>
+     * <p>The ARN of an AWS Lambda function invoked by Secrets Manager to rotate and
+     * expire the secret either automatically per the schedule or manually by a call to
+     * <a>RotateSecret</a>.</p>
      */
     inline SecretListEntry& WithRotationLambdaARN(const char* value) { SetRotationLambdaARN(value); return *this;}
 
@@ -413,38 +403,44 @@ namespace Model
 
 
     /**
-     * <p>The last date and time that the rotation process for this secret was
-     * invoked.</p>
+     * <p>The most recent date and time that the Secrets Manager rotation process was
+     * successfully completed. This value is null if the secret hasn't ever
+     * rotated.</p>
      */
     inline const Aws::Utils::DateTime& GetLastRotatedDate() const{ return m_lastRotatedDate; }
 
     /**
-     * <p>The last date and time that the rotation process for this secret was
-     * invoked.</p>
+     * <p>The most recent date and time that the Secrets Manager rotation process was
+     * successfully completed. This value is null if the secret hasn't ever
+     * rotated.</p>
      */
     inline bool LastRotatedDateHasBeenSet() const { return m_lastRotatedDateHasBeenSet; }
 
     /**
-     * <p>The last date and time that the rotation process for this secret was
-     * invoked.</p>
+     * <p>The most recent date and time that the Secrets Manager rotation process was
+     * successfully completed. This value is null if the secret hasn't ever
+     * rotated.</p>
      */
     inline void SetLastRotatedDate(const Aws::Utils::DateTime& value) { m_lastRotatedDateHasBeenSet = true; m_lastRotatedDate = value; }
 
     /**
-     * <p>The last date and time that the rotation process for this secret was
-     * invoked.</p>
+     * <p>The most recent date and time that the Secrets Manager rotation process was
+     * successfully completed. This value is null if the secret hasn't ever
+     * rotated.</p>
      */
     inline void SetLastRotatedDate(Aws::Utils::DateTime&& value) { m_lastRotatedDateHasBeenSet = true; m_lastRotatedDate = std::move(value); }
 
     /**
-     * <p>The last date and time that the rotation process for this secret was
-     * invoked.</p>
+     * <p>The most recent date and time that the Secrets Manager rotation process was
+     * successfully completed. This value is null if the secret hasn't ever
+     * rotated.</p>
      */
     inline SecretListEntry& WithLastRotatedDate(const Aws::Utils::DateTime& value) { SetLastRotatedDate(value); return *this;}
 
     /**
-     * <p>The last date and time that the rotation process for this secret was
-     * invoked.</p>
+     * <p>The most recent date and time that the Secrets Manager rotation process was
+     * successfully completed. This value is null if the secret hasn't ever
+     * rotated.</p>
      */
     inline SecretListEntry& WithLastRotatedDate(Aws::Utils::DateTime&& value) { SetLastRotatedDate(std::move(value)); return *this;}
 
@@ -518,7 +514,7 @@ namespace Model
 
 
     /**
-     * <p>The date and time on which this secret was deleted. Not present on active
+     * <p>The date and time the deletion of the secret occurred. Not present on active
      * secrets. The secret can be recovered until the number of days in the recovery
      * window has passed, as specified in the <code>RecoveryWindowInDays</code>
      * parameter of the <a>DeleteSecret</a> operation.</p>
@@ -526,7 +522,7 @@ namespace Model
     inline const Aws::Utils::DateTime& GetDeletedDate() const{ return m_deletedDate; }
 
     /**
-     * <p>The date and time on which this secret was deleted. Not present on active
+     * <p>The date and time the deletion of the secret occurred. Not present on active
      * secrets. The secret can be recovered until the number of days in the recovery
      * window has passed, as specified in the <code>RecoveryWindowInDays</code>
      * parameter of the <a>DeleteSecret</a> operation.</p>
@@ -534,7 +530,7 @@ namespace Model
     inline bool DeletedDateHasBeenSet() const { return m_deletedDateHasBeenSet; }
 
     /**
-     * <p>The date and time on which this secret was deleted. Not present on active
+     * <p>The date and time the deletion of the secret occurred. Not present on active
      * secrets. The secret can be recovered until the number of days in the recovery
      * window has passed, as specified in the <code>RecoveryWindowInDays</code>
      * parameter of the <a>DeleteSecret</a> operation.</p>
@@ -542,7 +538,7 @@ namespace Model
     inline void SetDeletedDate(const Aws::Utils::DateTime& value) { m_deletedDateHasBeenSet = true; m_deletedDate = value; }
 
     /**
-     * <p>The date and time on which this secret was deleted. Not present on active
+     * <p>The date and time the deletion of the secret occurred. Not present on active
      * secrets. The secret can be recovered until the number of days in the recovery
      * window has passed, as specified in the <code>RecoveryWindowInDays</code>
      * parameter of the <a>DeleteSecret</a> operation.</p>
@@ -550,7 +546,7 @@ namespace Model
     inline void SetDeletedDate(Aws::Utils::DateTime&& value) { m_deletedDateHasBeenSet = true; m_deletedDate = std::move(value); }
 
     /**
-     * <p>The date and time on which this secret was deleted. Not present on active
+     * <p>The date and time the deletion of the secret occurred. Not present on active
      * secrets. The secret can be recovered until the number of days in the recovery
      * window has passed, as specified in the <code>RecoveryWindowInDays</code>
      * parameter of the <a>DeleteSecret</a> operation.</p>
@@ -558,7 +554,7 @@ namespace Model
     inline SecretListEntry& WithDeletedDate(const Aws::Utils::DateTime& value) { SetDeletedDate(value); return *this;}
 
     /**
-     * <p>The date and time on which this secret was deleted. Not present on active
+     * <p>The date and time the deletion of the secret occurred. Not present on active
      * secrets. The secret can be recovered until the number of days in the recovery
      * window has passed, as specified in the <code>RecoveryWindowInDays</code>
      * parameter of the <a>DeleteSecret</a> operation.</p>
@@ -567,207 +563,287 @@ namespace Model
 
 
     /**
-     * <p>The list of user-defined tags that are associated with the secret. To add
-     * tags to a secret, use <a>TagResource</a>. To remove tags, use
-     * <a>UntagResource</a>.</p>
+     * <p>The list of user-defined tags associated with the secret. To add tags to a
+     * secret, use <a>TagResource</a>. To remove tags, use <a>UntagResource</a>.</p>
      */
     inline const Aws::Vector<Tag>& GetTags() const{ return m_tags; }
 
     /**
-     * <p>The list of user-defined tags that are associated with the secret. To add
-     * tags to a secret, use <a>TagResource</a>. To remove tags, use
-     * <a>UntagResource</a>.</p>
+     * <p>The list of user-defined tags associated with the secret. To add tags to a
+     * secret, use <a>TagResource</a>. To remove tags, use <a>UntagResource</a>.</p>
      */
     inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
 
     /**
-     * <p>The list of user-defined tags that are associated with the secret. To add
-     * tags to a secret, use <a>TagResource</a>. To remove tags, use
-     * <a>UntagResource</a>.</p>
+     * <p>The list of user-defined tags associated with the secret. To add tags to a
+     * secret, use <a>TagResource</a>. To remove tags, use <a>UntagResource</a>.</p>
      */
     inline void SetTags(const Aws::Vector<Tag>& value) { m_tagsHasBeenSet = true; m_tags = value; }
 
     /**
-     * <p>The list of user-defined tags that are associated with the secret. To add
-     * tags to a secret, use <a>TagResource</a>. To remove tags, use
-     * <a>UntagResource</a>.</p>
+     * <p>The list of user-defined tags associated with the secret. To add tags to a
+     * secret, use <a>TagResource</a>. To remove tags, use <a>UntagResource</a>.</p>
      */
     inline void SetTags(Aws::Vector<Tag>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
 
     /**
-     * <p>The list of user-defined tags that are associated with the secret. To add
-     * tags to a secret, use <a>TagResource</a>. To remove tags, use
-     * <a>UntagResource</a>.</p>
+     * <p>The list of user-defined tags associated with the secret. To add tags to a
+     * secret, use <a>TagResource</a>. To remove tags, use <a>UntagResource</a>.</p>
      */
     inline SecretListEntry& WithTags(const Aws::Vector<Tag>& value) { SetTags(value); return *this;}
 
     /**
-     * <p>The list of user-defined tags that are associated with the secret. To add
-     * tags to a secret, use <a>TagResource</a>. To remove tags, use
-     * <a>UntagResource</a>.</p>
+     * <p>The list of user-defined tags associated with the secret. To add tags to a
+     * secret, use <a>TagResource</a>. To remove tags, use <a>UntagResource</a>.</p>
      */
     inline SecretListEntry& WithTags(Aws::Vector<Tag>&& value) { SetTags(std::move(value)); return *this;}
 
     /**
-     * <p>The list of user-defined tags that are associated with the secret. To add
-     * tags to a secret, use <a>TagResource</a>. To remove tags, use
-     * <a>UntagResource</a>.</p>
+     * <p>The list of user-defined tags associated with the secret. To add tags to a
+     * secret, use <a>TagResource</a>. To remove tags, use <a>UntagResource</a>.</p>
      */
     inline SecretListEntry& AddTags(const Tag& value) { m_tagsHasBeenSet = true; m_tags.push_back(value); return *this; }
 
     /**
-     * <p>The list of user-defined tags that are associated with the secret. To add
-     * tags to a secret, use <a>TagResource</a>. To remove tags, use
-     * <a>UntagResource</a>.</p>
+     * <p>The list of user-defined tags associated with the secret. To add tags to a
+     * secret, use <a>TagResource</a>. To remove tags, use <a>UntagResource</a>.</p>
      */
     inline SecretListEntry& AddTags(Tag&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
 
 
     /**
      * <p>A list of all of the currently assigned <code>SecretVersionStage</code>
-     * staging labels and the <code>SecretVersionId</code> that each is attached to.
+     * staging labels and the <code>SecretVersionId</code> attached to each one.
      * Staging labels are used to keep track of the different versions during the
-     * rotation process.</p> <note> <p>A version that does not have any
+     * rotation process.</p>  <p>A version that does not have any
      * <code>SecretVersionStage</code> is considered deprecated and subject to
-     * deletion. Such versions are not included in this list.</p> </note>
+     * deletion. Such versions are not included in this list.</p> 
      */
     inline const Aws::Map<Aws::String, Aws::Vector<Aws::String>>& GetSecretVersionsToStages() const{ return m_secretVersionsToStages; }
 
     /**
      * <p>A list of all of the currently assigned <code>SecretVersionStage</code>
-     * staging labels and the <code>SecretVersionId</code> that each is attached to.
+     * staging labels and the <code>SecretVersionId</code> attached to each one.
      * Staging labels are used to keep track of the different versions during the
-     * rotation process.</p> <note> <p>A version that does not have any
+     * rotation process.</p>  <p>A version that does not have any
      * <code>SecretVersionStage</code> is considered deprecated and subject to
-     * deletion. Such versions are not included in this list.</p> </note>
+     * deletion. Such versions are not included in this list.</p> 
      */
     inline bool SecretVersionsToStagesHasBeenSet() const { return m_secretVersionsToStagesHasBeenSet; }
 
     /**
      * <p>A list of all of the currently assigned <code>SecretVersionStage</code>
-     * staging labels and the <code>SecretVersionId</code> that each is attached to.
+     * staging labels and the <code>SecretVersionId</code> attached to each one.
      * Staging labels are used to keep track of the different versions during the
-     * rotation process.</p> <note> <p>A version that does not have any
+     * rotation process.</p>  <p>A version that does not have any
      * <code>SecretVersionStage</code> is considered deprecated and subject to
-     * deletion. Such versions are not included in this list.</p> </note>
+     * deletion. Such versions are not included in this list.</p> 
      */
     inline void SetSecretVersionsToStages(const Aws::Map<Aws::String, Aws::Vector<Aws::String>>& value) { m_secretVersionsToStagesHasBeenSet = true; m_secretVersionsToStages = value; }
 
     /**
      * <p>A list of all of the currently assigned <code>SecretVersionStage</code>
-     * staging labels and the <code>SecretVersionId</code> that each is attached to.
+     * staging labels and the <code>SecretVersionId</code> attached to each one.
      * Staging labels are used to keep track of the different versions during the
-     * rotation process.</p> <note> <p>A version that does not have any
+     * rotation process.</p>  <p>A version that does not have any
      * <code>SecretVersionStage</code> is considered deprecated and subject to
-     * deletion. Such versions are not included in this list.</p> </note>
+     * deletion. Such versions are not included in this list.</p> 
      */
     inline void SetSecretVersionsToStages(Aws::Map<Aws::String, Aws::Vector<Aws::String>>&& value) { m_secretVersionsToStagesHasBeenSet = true; m_secretVersionsToStages = std::move(value); }
 
     /**
      * <p>A list of all of the currently assigned <code>SecretVersionStage</code>
-     * staging labels and the <code>SecretVersionId</code> that each is attached to.
+     * staging labels and the <code>SecretVersionId</code> attached to each one.
      * Staging labels are used to keep track of the different versions during the
-     * rotation process.</p> <note> <p>A version that does not have any
+     * rotation process.</p>  <p>A version that does not have any
      * <code>SecretVersionStage</code> is considered deprecated and subject to
-     * deletion. Such versions are not included in this list.</p> </note>
+     * deletion. Such versions are not included in this list.</p> 
      */
     inline SecretListEntry& WithSecretVersionsToStages(const Aws::Map<Aws::String, Aws::Vector<Aws::String>>& value) { SetSecretVersionsToStages(value); return *this;}
 
     /**
      * <p>A list of all of the currently assigned <code>SecretVersionStage</code>
-     * staging labels and the <code>SecretVersionId</code> that each is attached to.
+     * staging labels and the <code>SecretVersionId</code> attached to each one.
      * Staging labels are used to keep track of the different versions during the
-     * rotation process.</p> <note> <p>A version that does not have any
+     * rotation process.</p>  <p>A version that does not have any
      * <code>SecretVersionStage</code> is considered deprecated and subject to
-     * deletion. Such versions are not included in this list.</p> </note>
+     * deletion. Such versions are not included in this list.</p> 
      */
     inline SecretListEntry& WithSecretVersionsToStages(Aws::Map<Aws::String, Aws::Vector<Aws::String>>&& value) { SetSecretVersionsToStages(std::move(value)); return *this;}
 
     /**
      * <p>A list of all of the currently assigned <code>SecretVersionStage</code>
-     * staging labels and the <code>SecretVersionId</code> that each is attached to.
+     * staging labels and the <code>SecretVersionId</code> attached to each one.
      * Staging labels are used to keep track of the different versions during the
-     * rotation process.</p> <note> <p>A version that does not have any
+     * rotation process.</p>  <p>A version that does not have any
      * <code>SecretVersionStage</code> is considered deprecated and subject to
-     * deletion. Such versions are not included in this list.</p> </note>
+     * deletion. Such versions are not included in this list.</p> 
      */
     inline SecretListEntry& AddSecretVersionsToStages(const Aws::String& key, const Aws::Vector<Aws::String>& value) { m_secretVersionsToStagesHasBeenSet = true; m_secretVersionsToStages.emplace(key, value); return *this; }
 
     /**
      * <p>A list of all of the currently assigned <code>SecretVersionStage</code>
-     * staging labels and the <code>SecretVersionId</code> that each is attached to.
+     * staging labels and the <code>SecretVersionId</code> attached to each one.
      * Staging labels are used to keep track of the different versions during the
-     * rotation process.</p> <note> <p>A version that does not have any
+     * rotation process.</p>  <p>A version that does not have any
      * <code>SecretVersionStage</code> is considered deprecated and subject to
-     * deletion. Such versions are not included in this list.</p> </note>
+     * deletion. Such versions are not included in this list.</p> 
      */
     inline SecretListEntry& AddSecretVersionsToStages(Aws::String&& key, const Aws::Vector<Aws::String>& value) { m_secretVersionsToStagesHasBeenSet = true; m_secretVersionsToStages.emplace(std::move(key), value); return *this; }
 
     /**
      * <p>A list of all of the currently assigned <code>SecretVersionStage</code>
-     * staging labels and the <code>SecretVersionId</code> that each is attached to.
+     * staging labels and the <code>SecretVersionId</code> attached to each one.
      * Staging labels are used to keep track of the different versions during the
-     * rotation process.</p> <note> <p>A version that does not have any
+     * rotation process.</p>  <p>A version that does not have any
      * <code>SecretVersionStage</code> is considered deprecated and subject to
-     * deletion. Such versions are not included in this list.</p> </note>
+     * deletion. Such versions are not included in this list.</p> 
      */
     inline SecretListEntry& AddSecretVersionsToStages(const Aws::String& key, Aws::Vector<Aws::String>&& value) { m_secretVersionsToStagesHasBeenSet = true; m_secretVersionsToStages.emplace(key, std::move(value)); return *this; }
 
     /**
      * <p>A list of all of the currently assigned <code>SecretVersionStage</code>
-     * staging labels and the <code>SecretVersionId</code> that each is attached to.
+     * staging labels and the <code>SecretVersionId</code> attached to each one.
      * Staging labels are used to keep track of the different versions during the
-     * rotation process.</p> <note> <p>A version that does not have any
+     * rotation process.</p>  <p>A version that does not have any
      * <code>SecretVersionStage</code> is considered deprecated and subject to
-     * deletion. Such versions are not included in this list.</p> </note>
+     * deletion. Such versions are not included in this list.</p> 
      */
     inline SecretListEntry& AddSecretVersionsToStages(Aws::String&& key, Aws::Vector<Aws::String>&& value) { m_secretVersionsToStagesHasBeenSet = true; m_secretVersionsToStages.emplace(std::move(key), std::move(value)); return *this; }
 
     /**
      * <p>A list of all of the currently assigned <code>SecretVersionStage</code>
-     * staging labels and the <code>SecretVersionId</code> that each is attached to.
+     * staging labels and the <code>SecretVersionId</code> attached to each one.
      * Staging labels are used to keep track of the different versions during the
-     * rotation process.</p> <note> <p>A version that does not have any
+     * rotation process.</p>  <p>A version that does not have any
      * <code>SecretVersionStage</code> is considered deprecated and subject to
-     * deletion. Such versions are not included in this list.</p> </note>
+     * deletion. Such versions are not included in this list.</p> 
      */
     inline SecretListEntry& AddSecretVersionsToStages(const char* key, Aws::Vector<Aws::String>&& value) { m_secretVersionsToStagesHasBeenSet = true; m_secretVersionsToStages.emplace(key, std::move(value)); return *this; }
 
     /**
      * <p>A list of all of the currently assigned <code>SecretVersionStage</code>
-     * staging labels and the <code>SecretVersionId</code> that each is attached to.
+     * staging labels and the <code>SecretVersionId</code> attached to each one.
      * Staging labels are used to keep track of the different versions during the
-     * rotation process.</p> <note> <p>A version that does not have any
+     * rotation process.</p>  <p>A version that does not have any
      * <code>SecretVersionStage</code> is considered deprecated and subject to
-     * deletion. Such versions are not included in this list.</p> </note>
+     * deletion. Such versions are not included in this list.</p> 
      */
     inline SecretListEntry& AddSecretVersionsToStages(const char* key, const Aws::Vector<Aws::String>& value) { m_secretVersionsToStagesHasBeenSet = true; m_secretVersionsToStages.emplace(key, value); return *this; }
 
 
-    
+    /**
+     * <p>Returns the name of the service that created the secret.</p>
+     */
     inline const Aws::String& GetOwningService() const{ return m_owningService; }
 
-    
+    /**
+     * <p>Returns the name of the service that created the secret.</p>
+     */
     inline bool OwningServiceHasBeenSet() const { return m_owningServiceHasBeenSet; }
 
-    
+    /**
+     * <p>Returns the name of the service that created the secret.</p>
+     */
     inline void SetOwningService(const Aws::String& value) { m_owningServiceHasBeenSet = true; m_owningService = value; }
 
-    
+    /**
+     * <p>Returns the name of the service that created the secret.</p>
+     */
     inline void SetOwningService(Aws::String&& value) { m_owningServiceHasBeenSet = true; m_owningService = std::move(value); }
 
-    
+    /**
+     * <p>Returns the name of the service that created the secret.</p>
+     */
     inline void SetOwningService(const char* value) { m_owningServiceHasBeenSet = true; m_owningService.assign(value); }
 
-    
+    /**
+     * <p>Returns the name of the service that created the secret.</p>
+     */
     inline SecretListEntry& WithOwningService(const Aws::String& value) { SetOwningService(value); return *this;}
 
-    
+    /**
+     * <p>Returns the name of the service that created the secret.</p>
+     */
     inline SecretListEntry& WithOwningService(Aws::String&& value) { SetOwningService(std::move(value)); return *this;}
 
-    
+    /**
+     * <p>Returns the name of the service that created the secret.</p>
+     */
     inline SecretListEntry& WithOwningService(const char* value) { SetOwningService(value); return *this;}
 
+
+    /**
+     * <p>The date and time when a secret was created.</p>
+     */
+    inline const Aws::Utils::DateTime& GetCreatedDate() const{ return m_createdDate; }
+
+    /**
+     * <p>The date and time when a secret was created.</p>
+     */
+    inline bool CreatedDateHasBeenSet() const { return m_createdDateHasBeenSet; }
+
+    /**
+     * <p>The date and time when a secret was created.</p>
+     */
+    inline void SetCreatedDate(const Aws::Utils::DateTime& value) { m_createdDateHasBeenSet = true; m_createdDate = value; }
+
+    /**
+     * <p>The date and time when a secret was created.</p>
+     */
+    inline void SetCreatedDate(Aws::Utils::DateTime&& value) { m_createdDateHasBeenSet = true; m_createdDate = std::move(value); }
+
+    /**
+     * <p>The date and time when a secret was created.</p>
+     */
+    inline SecretListEntry& WithCreatedDate(const Aws::Utils::DateTime& value) { SetCreatedDate(value); return *this;}
+
+    /**
+     * <p>The date and time when a secret was created.</p>
+     */
+    inline SecretListEntry& WithCreatedDate(Aws::Utils::DateTime&& value) { SetCreatedDate(std::move(value)); return *this;}
+
+
+    /**
+     * <p>The Region where Secrets Manager originated the secret.</p>
+     */
+    inline const Aws::String& GetPrimaryRegion() const{ return m_primaryRegion; }
+
+    /**
+     * <p>The Region where Secrets Manager originated the secret.</p>
+     */
+    inline bool PrimaryRegionHasBeenSet() const { return m_primaryRegionHasBeenSet; }
+
+    /**
+     * <p>The Region where Secrets Manager originated the secret.</p>
+     */
+    inline void SetPrimaryRegion(const Aws::String& value) { m_primaryRegionHasBeenSet = true; m_primaryRegion = value; }
+
+    /**
+     * <p>The Region where Secrets Manager originated the secret.</p>
+     */
+    inline void SetPrimaryRegion(Aws::String&& value) { m_primaryRegionHasBeenSet = true; m_primaryRegion = std::move(value); }
+
+    /**
+     * <p>The Region where Secrets Manager originated the secret.</p>
+     */
+    inline void SetPrimaryRegion(const char* value) { m_primaryRegionHasBeenSet = true; m_primaryRegion.assign(value); }
+
+    /**
+     * <p>The Region where Secrets Manager originated the secret.</p>
+     */
+    inline SecretListEntry& WithPrimaryRegion(const Aws::String& value) { SetPrimaryRegion(value); return *this;}
+
+    /**
+     * <p>The Region where Secrets Manager originated the secret.</p>
+     */
+    inline SecretListEntry& WithPrimaryRegion(Aws::String&& value) { SetPrimaryRegion(std::move(value)); return *this;}
+
+    /**
+     * <p>The Region where Secrets Manager originated the secret.</p>
+     */
+    inline SecretListEntry& WithPrimaryRegion(const char* value) { SetPrimaryRegion(value); return *this;}
+
   private:
 
     Aws::String m_aRN;
@@ -811,6 +887,12 @@ namespace Model
 
     Aws::String m_owningService;
     bool m_owningServiceHasBeenSet;
+
+    Aws::Utils::DateTime m_createdDate;
+    bool m_createdDateHasBeenSet;
+
+    Aws::String m_primaryRegion;
+    bool m_primaryRegionHasBeenSet;
   };
 
 } // namespace Model
